@@ -142,7 +142,7 @@ akaike_information (world_fmt * world, long *Gmax)
   create_nr (nr, world, *Gmax, 0, world->loci, world->repkind, world->rep);
 
   SETUPPARAM0 (world, nr, world->repkind, repstart, repstop,
-		    world->loci, kind, multilocus);
+	       world->loci, kind, multilocus);
 
   memcpy (savecustm, world->options->custm2, sizeof (char) * nr->numpop2);
   memcpy (savecustm2, world->options->custm, sizeof (char) * nr->numpop2);
@@ -187,7 +187,8 @@ akaike_information (world_fmt * world, long *Gmax)
       // aic scores based on averaging M (not 4Nm)
 
       memcpy (world->options->custm2, savecustm, sizeof (char) * nr->numpop2);
-      aic_score (&aicvec, &aicnum, nr, 0, world->numpop, temppattern, param0, 'm');
+      aic_score (&aicvec, &aicnum, nr, 0, world->numpop, temppattern, param0,
+		 'm');
       memcpy (world->options->custm2, savecustm, sizeof (char) * nr->numpop2);
       //  aic_score_minus(&aicvec, &aicnum, nr, 0 , world->numpop2-1, 
       //          temppattern, param0);
