@@ -40,15 +40,13 @@ double calc_locus_like (nr_fmt * nr, double *param, double *lparam,
 			long locus);
 void param_all_adjust (double *xv, worldoption_fmt * wopt, long numpop);
 void gradient (double *d, nr_fmt * nr, long locus);
-double probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr);
-double
-probG2 (double *param, double *lparam, double *sm,
-	double *kt, double *km, double *p, double *mindex,
-	int *msta, int *me, long numpop);
-void
-probG3 (double *apg, double *apg0r, timearchive_fmt * tyme,
-	long numpop, double *apgmax,
-	double *param, double *lparam, double *sm);
+double probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr,
+	      long locus);
+double probG2 (double *param, double *lparam, double *sm, double *kt,
+	       double *km, double *p, double *mindex, int *msta, int *me,
+	       long numpop);
+void probG3 (double *apg, double *apg0r, timearchive_fmt * tyme, long numpop,
+	     double *apgmax, double *param, double *lparam, double *sm);
 double probG4 (double *fullparam, double *data, long numpop, long numpop2);
 double logprob_noevent (world_fmt * world, long interval);
 double sum_migprob (world_fmt * world, long pop, long interval);
@@ -66,7 +64,8 @@ void grad2loggrad (double *param, long *indeks, double *d, long nn,
 		   long profilenum);
 void log_param0 (double *param, double *lparam, long nn);
 void copies2lcopies (timearchive_fmt * atl);
-void create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme);
+void create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme,
+		  long locus);
 
 
 void force_sametheta (double *param, worldoption_fmt * wopt, long numpop);
@@ -223,7 +222,7 @@ calc_line (helper_fmt * helper, double a, double b, double c,
 }
 
 double
-psi (double lamda, helper_fmt * helper,double *param, double *lparam)
+psi (double lamda, helper_fmt * helper, double *param, double *lparam)
 {
   double like;
   calc_loci_param (helper->nr, helper->nr->lparam, helper->xv,
@@ -231,8 +230,7 @@ psi (double lamda, helper_fmt * helper,double *param, double *lparam)
   set_expparam (helper->nr->param, helper->nr->lparam, helper->nr->partsize);
   fill_helper (helper, helper->nr->param, helper->nr->lparam,
 	       helper->nr->world, helper->nr);
-  like =
-    CALCLIKE (helper, helper->nr->param, helper->nr->lparam);
+  like = CALCLIKE (helper, helper->nr->param, helper->nr->lparam);
   return -like;
 }
 
@@ -318,7 +316,8 @@ absmaxvec (double *v, long n)
   return max;
 }
 
-void create_nr (nr_fmt * nr, world_fmt * world, long G,
+void
+create_nr (nr_fmt * nr, world_fmt * world, long G,
 	   long profilenum, long thislocus, long repkind, long rep)
 {
   long i;
@@ -334,7 +333,7 @@ void create_nr (nr_fmt * nr, world_fmt * world, long G,
   nr->profilenum = profilenum;
   nr->apg_max = (double *) calloc (world->loci + 1, sizeof (double));
   nr->PGC = (double *) calloc (world->loci + 1, sizeof (double));
-  if (myID == MASTER && world->options->gamma && world->locus >= world->loci)
+  if (/*myID == MASTER && */ world->options->gamma /* && world->locus >= world->loci*/)
     {
       nr->categs = GAMMA_INTERVALS;
       nr->rate = (double *) calloc (nr->categs, sizeof (double));
@@ -380,10 +379,10 @@ void create_nr (nr_fmt * nr, world_fmt * world, long G,
   nr->profiles = (long *) calloc (world->numpop2 + 1, sizeof (long));
   nr->values = (double *) calloc (world->numpop2 + 1, sizeof (double));
   nr->indeks = (long *) calloc (nr->partsize, sizeof (long));
- // allocate earlier in world: alloc_apg (&nr->apg0, world->repstop, world->loci, G);
- // allicate earlier in world:  alloc_apg (&nr->apg, world->repstop, world->loci, G);
- nr->apg = world->apg;
- nr->apg0 = world->apg0;
+  // allocate earlier in world: alloc_apg (&nr->apg0, world->repstop, world->loci, G);
+  // allicate earlier in world:  alloc_apg (&nr->apg, world->repstop, world->loci, G);
+  nr->apg = world->apg;
+  nr->apg0 = world->apg0;
 }
 
 void
@@ -480,15 +479,15 @@ destroy_nr (nr_fmt * nr, world_fmt * world)
   free (nr->datalike);
   free (nr->apg_max);
   free (nr->PGC);
- /* for (j = world->repstop - 1; j >= 0; j--)
-    {
-      free (nr->apg0[j][0]);
-      free (nr->apg0[j]);
-      free (nr->apg[j][0]);
-      free (nr->apg[j]);
-    }
-  free (nr->apg0);
-  free (nr->apg);*/
+  /* for (j = world->repstop - 1; j >= 0; j--)
+     {
+     free (nr->apg0[j][0]);
+     free (nr->apg0[j]);
+     free (nr->apg[j][0]);
+     free (nr->apg[j]);
+     }
+     free (nr->apg0);
+     free (nr->apg); */
   free (nr->profiles);
   free (nr->values);
   free (nr->indeks);
@@ -520,7 +519,9 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
   double *locallparam;
   double *localparam;
   double *sm;
-  //  double temp;
+  double mu_rate = nr->world->options->mu_rates[locus];
+  double lmu_rate = nr->world->options->lmu_rates[locus];
+//  double temp;
   locallparam = (double *) calloc ((numpop2 + numpop + numpop),
 				   sizeof (double));
   localparam = locallparam + numpop2;
@@ -534,14 +535,14 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
 
   for (r = 0; r < nr->numpop; r++)
     {
-      locallparam[r] = LOG2 - locallparam[r];
-      localparam[r] = 1. / localparam[r];
+      locallparam[r] = LOG2 - (locallparam[r] + lmu_rate);
+      localparam[r] = 1. / (localparam[r] * mu_rate);
       msta = nr->mstart[r];
       msto = nr->mend[r];
       for (j = msta; j < msto; j++)
 	{
-	  sm[r] += geo[j] * param[j];
-	  locallparam[j] += lgeo[j];
+	  sm[r] += geo[j] * param[j] / mu_rate;
+	  locallparam[j] += lgeo[j] - lmu_rate;
 	}
     }
   gsum = 0;
@@ -838,7 +839,8 @@ gradient (double *d, nr_fmt * nr, long locus)
   double expapg, *thetas, *m;
   double *geo = nr->world->data->geo;
   tarchive_fmt *tl;
-
+  double tet;
+  double mu_rate = nr->world->options->mu_rates[locus];
   //  long model = nr->world->options->migration_model;
   memset (d, 0, sizeof (double) * nr->numpop2);
   thetas = nr->param;
@@ -853,8 +855,9 @@ gradient (double *d, nr_fmt * nr, long locus)
 	  expapg = EXP (nr->apg[r][locus][g]);
 	  for (pop = 0; pop < numpop; pop++)
 	    {
-	      nr->parts[pop] = -tl[g].p[pop] / thetas[pop]
-		+ tl[g].kt[pop] / (thetas[pop] * thetas[pop]);
+	      tet = thetas[pop];
+	      nr->parts[pop] = -tl[g].p[pop] / tet
+		+ tl[g].kt[pop] / (tet * tet * mu_rate);
 
 	      msta = nr->mstart[pop];
 	      msto = nr->mend[pop];
@@ -876,8 +879,8 @@ gradient (double *d, nr_fmt * nr, long locus)
 		         nr->param[pop]/(2.*nr->param[otherpop]));
 		         }
 		         else */
-		      nr->parts[i] = ((tl[g].mindex[i] / nr->param[i])
-				      - geo[i] * tl[g].km[pop]);
+		      nr->parts[i] = ((tl[g].mindex[i] / (nr->param[i]))
+				      - geo[i] * tl[g].km[pop] / mu_rate);
 		    }
 		}
 	    }
@@ -1156,18 +1159,21 @@ grad2loggrad (double *param, long *indeks, double *d, long nn,
 }
 
 double
-probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr)
+probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr,
+       long locus)
 {
   const int numpop = (int) nr->numpop;
   int i, j, msta, msto;
   double result = 0., sm;
   double *geo = nr->world->data->geo;
   double *lgeo = nr->world->data->lgeo;
+  double mu_rate = nr->world->options->mu_rates[locus];
+  double lmu_rate = nr->world->options->lmu_rates[locus];
   for (i = 0; i < numpop; i++)
     {
       if (lparam[i] <= -DBL_MAX)
 	return DBL_MAX;
-      result += tl->p[i] * (LOG2 - lparam[i]);
+      result += tl->p[i] * (LOG2 - (lparam[i] + lmu_rate));
       msta = nr->mstart[i];
       msto = nr->mend[i];
       sm = 0.0;
@@ -1175,11 +1181,11 @@ probG (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr)
 	{
 	  if (param[j] > 0.0)
 	    {
-	      result += tl->mindex[j] * (lgeo[j] + lparam[j]);
-	      sm += geo[j] * param[j];
+	      result += tl->mindex[j] * (lgeo[j] + lparam[j] - lmu_rate);
+	      sm += geo[j] * param[j] / mu_rate;
 	    }
 	}
-      result += -tl->km[i] * sm - tl->kt[i] / param[i];
+      result += -tl->km[i] * sm - tl->kt[i] / (param[i] * mu_rate);
     }
   return result;
 }
@@ -1207,7 +1213,7 @@ probG4 (double *fullparam, double *data, long numpop, long numpop2)
     }
   // - kt * 1/theta - km * sm
   for (i = numpop2; i < numpop2 + 2 * numpop; i++)
-    {	
+    {
       result -= fullparam[i] * data[i];
     }
   return result;
@@ -1495,7 +1501,7 @@ copies2lcopies (timearchive_fmt * atl)
 }
 
 void
-create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme)
+create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme, long locus)
 {
   long g;
   long copies;
@@ -1509,7 +1515,8 @@ create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme)
       if (copies == 0)
 	apg0[g] = -DBL_MAX;
       else
-	apg0[g] = probG (tyme->param0, tyme->lparam0, &tyme->tl[g], nr);
+	apg0[g] =
+	  probG (tyme->param0, tyme->lparam0, &tyme->tl[g], nr, locus);
     }
 }
 
