@@ -44,9 +44,10 @@ extern void simple_loci_derivatives (double *d, nr_fmt * nr,
 				     timearchive_fmt ** tyme, long locus);
 extern void copy_and_clear_d (nr_fmt * nr);
 extern void add_back_d (nr_fmt * nr);
-extern void setup_parameter0_standard (world_fmt * world, nr_fmt * nr, long repkind,
-			      long repstart, long repstop, long loci,
-			      long kind, boolean multilocus);
+extern void setup_parameter0_standard (world_fmt * world, nr_fmt * nr,
+				       long repkind, long repstart,
+				       long repstop, long loci, long kind,
+				       boolean multilocus);
 
 extern void combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv);
 
@@ -59,6 +60,10 @@ extern long do_profiles (world_fmt * world, nr_fmt * nr, double *likes,
 extern void fill_helper (helper_fmt * helper, double *param, double *lparam,
 			 world_fmt * world, nr_fmt * nr);
 
+extern void replace_with (int mode, double *a, double *b, double *c, double m,
+		   double *la, double *lb, double *lc, double ll);
+double quadratic_lamda (double lamda, double a, double b, double c, double la,
+			double lb, double lc);
 
 
 #endif /* COMBINE_INCLUDE */
