@@ -49,9 +49,10 @@ $Id: combroyden2.c,v 1.74 2001/09/07 23:56:13 beerli Exp $
 // for speed reasons we don't want any further indirection
 // for which we have no use.
 #ifdef SLOWNET
- double (*calc_like) (helper_fmt *, double *, double *);
- void (*calc_gradient) (nr_fmt *, helper_fmt *, double *);
- void (*setup_param0) (world_fmt * , nr_fmt * , long , long , long , long , long , boolean );
+double (*calc_like) (helper_fmt *, double *, double *);
+void (*calc_gradient) (nr_fmt *, helper_fmt *, double *);
+void (*setup_param0) (world_fmt *, nr_fmt *, long, long, long, long, long,
+		      boolean);
 #endif
 
 extern void debug_plot (helper_fmt * helper);
@@ -76,7 +77,8 @@ void calc_meanparam (world_fmt * world, long n, long repstart, long repstop);
 /* multilocus first derivatives with or without gamma distrib. mut. rate */
 void combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv);
 #ifdef SLOWNET
-void slow_net_combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv);
+void slow_net_combine_gradient (nr_fmt * nr, helper_fmt * helper,
+				double *gxv);
 #endif
 /* this helps to use the simple single locus material */
 void copy_and_clear_d (nr_fmt * nr);
@@ -88,7 +90,8 @@ void set_gamma_param (double *paramn, double *paramo,
 /* calculates norm, this creates a stopping criteria */
 double norm (double *d, long size);
 /* used in multilocus  line search */
-double psilo (double lamda, helper_fmt * helper, double *param, double *lparam);
+double psilo (double lamda, helper_fmt * helper, double *param,
+	      double *lparam);
 /* used in integral for gamma distr. mutation rate */
 double phi (double t, helper_fmt * b);
 
@@ -100,8 +103,11 @@ void reset_work (double **work, long nnn);
 
 /* linesearch of BFGS
    and helper functions for this linesearch */
-double line_search (double *dv, double *gxv, double (*fpsi) (double lamda, helper_fmt * helper, double *param, double *lparam),
-		    helper_fmt * thishelper, double oldL, double *tempparam, double *templparam);
+double line_search (double *dv, double *gxv,
+		    double (*fpsi) (double lamda, helper_fmt * helper,
+				    double *param, double *lparam),
+		    helper_fmt * thishelper, double oldL, double *tempparam,
+		    double *templparam);
 
 void replace_with (int mode, double *a, double *b, double *c, double m,
 		   double *la, double *lb, double *lc, double ll);
@@ -133,8 +139,8 @@ void profile_setup (long profilenum, long *profiles, double *param,
 		    double *value, long *nnn);
 
 void setup_parameter0_standard (world_fmt * world, nr_fmt * nr, long repkind,
-		       long repstart, long repstop, long loci, long kind,
-		       boolean multilocus);
+				long repstart, long repstop, long loci,
+				long kind, boolean multilocus);
 
 void report_broyden (double newL, double normd, long trials,
 		     boolean boolgamma, double theta1, double alpha,
@@ -178,7 +184,7 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
 #else
   long repstart, repstop;
 #endif
-boolean multilocus;
+  boolean multilocus;
   nr_fmt *nr;
   nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
   if (kind == MULTILOCUS)
@@ -189,11 +195,12 @@ boolean multilocus;
     }
 
   create_nr (nr, world, G, 0, world->locus, repkind, rep);
-   set_replicates (world, world->repkind, world->rep, &nr->repstart, &nr->repstop);
-   prepare_broyden(kind, world, &multilocus);
+  set_replicates (world, world->repkind, world->rep, &nr->repstart,
+		  &nr->repstop);
+  prepare_broyden (kind, world, &multilocus);
   SETUPPARAM0 (world, nr, world->repkind, nr->repstart, nr->repstop,
-				world->loci, kind, multilocus);
-  
+	       world->loci, kind, multilocus);
+
   doublevec1d (&param, nr->partsize + 1);
 
 #ifdef MPI
@@ -258,6 +265,7 @@ calc_loci_like (helper_fmt * helper, double *param, double *lparam)
 {
 #ifndef MPI
   long locus;
+  double *mu_rates = helper->nr->world->options->mu_rates;
 #endif
   nr_fmt *nr = helper->nr;
   world_fmt *world = helper->nr->world;
@@ -277,24 +285,14 @@ calc_loci_like (helper_fmt * helper, double *param, double *lparam)
 	    {
 	      if (nr->skiploci[locus])
 		continue;
-	      nr->locilikes[locus] = calc_locus_like (nr, param, lparam, locus);
+	      nr->locilikes[locus] =
+		calc_locus_like (nr, param, lparam, locus) + mu_rates[locus];
 	      logres += nr->locilikes[locus];
 	    }
 	}
       else
 	{
-#ifdef LAGUERRE
-	  logres = gamma_loci_like (nr,  param, lparam, helper->weight);
-#else
-	  for (locus = 0; locus < world->loci; locus++)
-	    {
-	      if (nr->skiploci[locus])
-		continue;
-	      helper->locus = locus;
-	      helper->nr->locilikes[locus] = calc_single_gammalike (helper);
-	      logres += helper->nr->locilikes[locus];
-	    }
-#endif /* NOT LAGUERRE */
+	  logres = gamma_loci_like (helper, param, lparam, helper->weight);
 	}
 #endif /* NOT MPI */
     }
@@ -303,6 +301,7 @@ calc_loci_like (helper_fmt * helper, double *param, double *lparam)
   nr->llike = logres;
   return nr->llike;
 }
+
 #ifdef SLOWNET
 /* calculates the likelihood over all loci for the new parameter set */
 double
@@ -320,13 +319,14 @@ slow_net_calc_loci_like (helper_fmt * helper, double *param, double *lparam)
 	    {
 	      if (nr->skiploci[locus])
 		continue;
-	      nr->locilikes[locus] = calc_locus_like (nr, param, lparam, locus);
+	      nr->locilikes[locus] =
+		calc_locus_like (nr, param, lparam, locus);
 	      logres += nr->locilikes[locus];
 	    }
 	}
       else
 	{
-	  logres = gamma_loci_like (nr, param, lparam, helper->weight);
+	  logres = gamma_loci_like (helper, param, lparam, helper->weight);
 	}
     }
   else				/* ->singlelocus */
@@ -366,67 +366,73 @@ phi (double t, helper_fmt *b)
 */
 /* private functions---------------------------------------------- */
 /* derivatives */
-void
+  void
 combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv)
 {
 #ifndef MPI
   long locus;
 #endif
   timearchive_fmt **tyme = NULL;
-
+//    double save_a, denom, fla, fha, la, ha; 
   long nnn = nr->partsize - nr->profilenum;
   memset (gxv, 0, sizeof (double) * nnn);
   if (helper->analystype == SINGLELOCUS)
     {
       simple_loci_derivatives (gxv, nr, tyme, nr->world->locus);
-      force_symmetric_d (gxv, nr->world->options->migration_model, nr, nnn);
-      grad2loggrad (helper->expxv, nr->indeks, gxv, nnn, nr->profilenum);
     }
   else
-    {
-      if (!helper->boolgamma)
 	{
 #ifdef MPI
-	  if (myID == MASTER)
+	if (myID == MASTER)
 	    {
-	      mpi_gradient_master (nr, nr->world, nr->world->who);
-	      memcpy (gxv, nr->d, sizeof (double) * nr->partsize);
+		mpi_gradient_master (nr, nr->world, nr->world->who);
+		memcpy (gxv, nr->d, sizeof (double) * nr->partsize);
 	    }
 	  else			//SLAVE
 	    {
-	      error ("not allowed to execute mpi_gradient_worker()\n");
+		error ("not allowed to execute mpi_gradient_worker()\n");
 	    }
 #else
-	  for (locus = 0; locus < nr->world->loci; locus++)
-	    {
-	      if (nr->skiploci[locus])
-		continue;
-	      memset (nr->d, 0, sizeof (double) * nnn);
-	      simple_loci_derivatives (nr->d, nr, tyme, locus);
-	      add_vector (gxv, nr->d, nnn);
-	    }
-#endif
-
-	  force_symmetric_d (gxv, nr->world->options->migration_model, nr,
-			     nnn);
-	  grad2loggrad (helper->expxv, nr->indeks, gxv, nnn, nr->profilenum);
+	if (!helper->boolgamma)
+	{
+		for (locus = 0; locus < nr->world->loci; locus++)
+		{
+			if (nr->skiploci[locus])
+				continue;
+			memset (nr->d, 0, sizeof (double) * nnn);
+			simple_loci_derivatives (nr->d, nr, tyme, locus);
+			add_vector (gxv, nr->d, nnn);
+		}
 	}
       else
 	{
-#ifdef LAGUERRE
+//#ifdef LAGUERRE
 	  //if(nr->normd<5.)
-	  //    gamma_loci_difference(helper);
+	   //   gamma_loci_difference(helper);
 	  //else
 	  gamma_loci_derivative (helper);
 	  memcpy (gxv, nr->d, sizeof (double) * nr->partsize);
-#else
-	  dt (gxv, helper);
-#endif
-	  force_symmetric_d (gxv, nr->world->options->migration_model,
-			     nr, nnn);
-	  grad2loggrad (helper->expxv, nr->indeks, gxv, nnn, nr->profilenum);
+/*	  save_a = helper->xv[nr->partsize-1];
+	  la= save_a - save_a/100.;
+	  helper->xv[nr->partsize-1]=la;
+	  helper->expxv[nr->partsize-1]=exp(la);
+	  denom = -LGAMMA(helper->expxv[nr->partsize-1]) - (helper->xv[0]-helper->xv[nr->partsize-1]) * helper->xv[nr->partsize-1];
+	  fla = gamma_loci_like (helper, helper->expxv, helper->xv, denom);
+	  ha= save_a + save_a/100.;
+	  helper->xv[nr->partsize-1]=ha;
+	  helper->expxv[nr->partsize-1]=exp(ha);
+	  denom = -LGAMMA(helper->expxv[nr->partsize-1]) - (helper->xv[0]-helper->xv[nr->partsize-1]) * helper->xv[nr->partsize-1];
+	  fha = gamma_loci_like (helper, helper->expxv, helper->xv, denom);
+	  nr->d[nr->partsize-1] = (fla - fha)/(la-ha);
+	  memcpy (gxv, nr->d, sizeof (double) * nr->partsize);*/
+//#else
+//	  dt (gxv, helper);
+//endif  /*LAGUERRE*/
 	}
+#endif /*MPI*/
     }
+    force_symmetric_d (gxv, nr->world->options->migration_model, nr, nnn);
+    grad2loggrad (helper->expxv, nr->indeks, gxv, nnn, nr->profilenum);
 }
 
 #ifdef SLOWNET
@@ -546,20 +552,21 @@ void
 print_reset_big_param (FILE * file, double average, double maxtheta, long pop)
 {
   static boolean checkparam[MAXPOP];
-  static boolean done=FALSE;
+  static boolean done = FALSE;
   static char nowstr[STRSIZE];
-  if(!done)
+  if (!done)
     {
-      done=TRUE;
-      memset(&checkparam,0,sizeof(boolean)*1000);
+      done = TRUE;
+      memset (&checkparam, 0, sizeof (boolean) * 1000);
     }
-  if(!checkparam[pop])
+  if (!checkparam[pop])
     {
       get_time (nowstr, "%H:%M:%S");
-      fprintf (file, "%s   Theta for population %li was reset to the average\n",
+      fprintf (file,
+	       "%s   Theta for population %li was reset to the average\n",
 	       nowstr, pop);
-      fprintf (file, "          of %f, it exceeded the maximum of %f \n", average,
-	       maxtheta);
+      fprintf (file, "          of %f, it exceeded the maximum of %f \n",
+	       average, maxtheta);
     }
 }
 
@@ -637,9 +644,12 @@ calc_loci_param (nr_fmt * nr, double *lparam, double *olparam, double *dv,
   if (nr->world->locus >= nr->world->loci && nr->world->options->gamma)
     {
       if (lparam[nr->numpop2] > 9.903487553)
-	lparam[nr->numpop2] = 9.903487553;
-      initgammacat (nr->categs, EXP (lparam[nr->numpop2]), EXP (lparam[0]),
+	{  
+		lparam[nr->numpop2] = 9.903487553;
+	}
+		initgammacat (nr->categs, EXP (lparam[nr->numpop2]),1./* EXP (lparam[0])*/,
 		    nr->rate, nr->probcat);
+	//}
     }
 #endif
 
@@ -767,11 +777,12 @@ void partfree_helper(helper_fmt *in)
 }
 */
 
-double calc_d_g(double *d, double *g, long n)
+double
+calc_d_g (double *d, double *g, long n)
 {
   long i;
-  double sum=0.;
-  for(i=0;i<n;i++)
+  double sum = 0.;
+  for (i = 0; i < n; i++)
     sum += d[i] * g[i];
   return sum;
 }
@@ -793,11 +804,13 @@ double calc_d_g(double *d, double *g, long n)
    needs functions: psil, replace_with, quadratic_lamda
  */
 double
-line_search (double *dv, double *gxv, double (*fpsi) (double lamda, helper_fmt * helper, double *param, double *lparam),
-	     helper_fmt * thishelper, double oldL, double *tempparam, double *templparam)
+line_search (double *dv, double *gxv,
+	     double (*fpsi) (double lamda, helper_fmt * helper, double *param,
+			     double *lparam), helper_fmt * thishelper,
+	     double oldL, double *tempparam, double *templparam)
 {
   long trials = 0;
-  double locallamda=STARTLAMBDA, ql;
+  double locallamda = STARTLAMBDA, ql;
   double a, b, c;
   double psiabc;
   double ll, la, lb, lc;
@@ -809,22 +822,24 @@ line_search (double *dv, double *gxv, double (*fpsi) (double lamda, helper_fmt *
   b = 1.0;
 
   la = -oldL;
-  lb = -oldL; //(*fpsi) (b, &helper, tempparam, templparam);
+  lb = -oldL;			//(*fpsi) (b, &helper, tempparam, templparam);
   //  ll = (*fpsi) (m, &helper, tempparam, templparam);
   //if(ll > la)
   //  c =  -1.; 
   //else
   //  c = -2.;
-  c = calc_d_g(dv, gxv, helper.nr->partsize);
+  c = calc_d_g (dv, gxv, helper.nr->partsize);
   lc = (*fpsi) (c, &helper, tempparam, templparam);
   while (trials++ < NTRIALS)
     {
 //            printf ("*%3li> %f %f %f / %f %f %f\n", trials, a, b, c, la, lb, lc);
       locallamda =
-      (c * c * (lb - la) + b * b * (la - lc) +
-       a * a * (lc - lb)) / (2. * (b * la - c * la - a * lb + c * lb +
-      			     a * lc - b * lc));
-      psiabc = ((la - lb)/(-a + b) + (la - lc)/(a - c))/(-b + c);
+	(c * c * (lb - la) + b * b * (la - lc) +
+	 a * a * (lc - lb)) / (2. * (b * la - c * la - a * lb + c * lb +
+				     a * lc - b * lc));
+	if(isnan(locallamda))
+		return 1.;
+      psiabc = ((la - lb) / (-a + b) + (la - lc) / (a - c)) / (-b + c);
       if ((psiabc <= 0.0) || (locallamda >= m))
 	{
 	  if ((a == m || b == m || c == m))
@@ -850,11 +865,12 @@ line_search (double *dv, double *gxv, double (*fpsi) (double lamda, helper_fmt *
 	     return locallamda;
 	     if(((a<c<b) || (b<c<a)) && (lc < MIN(la,lb)))
 	     return locallamda; */
-	  replace_with (STARTLAMBDA, &a, &b, &c, locallamda, &la, &lb, &lc, ll);
+	  replace_with (STARTLAMBDA, &a, &b, &c, locallamda, &la, &lb, &lc,
+			ll);
 	  m = MYMAX3 (a, b, c);
 	}
     }
-  
+
   return locallamda;
 }
 
@@ -1027,8 +1043,8 @@ correct_values (world_fmt * world, nr_fmt * nr)
 	  if (world->options->writelog)
 	    print_reset_big_param (world->options->logfile,
 				   world->param0[pop], BIGGEST_THETA, pop);
-//	  print_reset_big_param (stdout, world->param0[pop], BIGGEST_THETA,
-//				 pop);
+//        print_reset_big_param (stdout, world->param0[pop], BIGGEST_THETA,
+//                               pop);
 	}
     }
   z = 0;
@@ -1049,16 +1065,28 @@ which_calc_like (long kind)
     {
     case PROFILE:
 #ifdef SLOWNET
-      calc_like = (double (*)(helper_fmt *, double *, double *)) slow_net_calc_loci_like;
-	calc_gradient =  (void (*)(nr_fmt *, helper_fmt *, double *)) slow_net_combine_gradient;
-	setup_param0 = (void (*)(world_fmt * , nr_fmt * , long , long , long , long , long , boolean )) setup_parameter0_slowmpi;
+      calc_like =
+	(double (*)(helper_fmt *, double *, double *))
+	slow_net_calc_loci_like;
+      calc_gradient =
+	(void (*)(nr_fmt *, helper_fmt *, double *))
+	slow_net_combine_gradient;
+      setup_param0 =
+	(void (*)
+	 (world_fmt *, nr_fmt *, long, long, long, long, long,
+	  boolean)) setup_parameter0_slowmpi;
 #endif
-	break;
+      break;
     default:
 #ifdef SLOWNET
-      calc_like = (double (*)(helper_fmt *, double *, double *)) calc_loci_like;
-      calc_gradient =  (void (*)(nr_fmt *, helper_fmt *, double *)) combine_gradient;
-      setup_param0 = (void (*)(world_fmt * , nr_fmt * , long , long , long , long , long , boolean )) setup_parameter0_mpi;
+      calc_like =
+	(double (*)(helper_fmt *, double *, double *)) calc_loci_like;
+      calc_gradient =
+	(void (*)(nr_fmt *, helper_fmt *, double *)) combine_gradient;
+      setup_param0 =
+	(void (*)
+	 (world_fmt *, nr_fmt *, long, long, long, long, long,
+	  boolean)) setup_parameter0_mpi;
 #endif
       break;
     }
@@ -1113,6 +1141,7 @@ multilocus_gamma_adjust (boolean multilocus, boolean boolgamma,
 	    (double *) realloc (world->param0,
 				sizeof (double) * (nn > 0 ? nn : 1));
 	  world->param0[world->numpop2] = world->options->alphavalue;
+
 	}
     }
   else
@@ -1140,59 +1169,59 @@ profile_setup (long profilenum, long *profiles, double *param, double *value,
 
 
 void
-setup_parameter0_standard (world_fmt * world, nr_fmt * nr, long repkind, long repstart,
-		  long repstop, long loci, long kind, boolean multilocus)
+setup_parameter0_standard (world_fmt * world, nr_fmt * nr, long repkind,
+			   long repstart, long repstop, long loci, long kind,
+			   boolean multilocus)
 {
   long locus, r;
-      if (multilocus)
-	{
-	  for (locus = 0; locus < loci; locus++)
-	    {
-	      if (repkind == SINGLECHAIN)
-		{
-		  for (r = repstart; r < repstop; r++)
-		    create_apg0 (nr->apg0[r][locus], nr,
-				 &world->atl[r][locus]);
-		}
-	      else
-		{
-		  if (kind != PROFILE)
-		    {
-		      for (r = repstart; r < repstop; r++)
-			create_apg0 (nr->apg0[r][locus], nr,
-				     &world->atl[r][locus]);
-		      interpolate_like (nr, locus);
-		    }
-		  else
-		    {
-		      for (r = repstart; r < repstop; r++)
-			create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
-		    }
-		}
-	    }
-	}
-      else			//single locus
+  if (multilocus)
+    {
+      for (locus = 0; locus < loci; locus++)
 	{
 	  if (repkind == SINGLECHAIN)
 	    {
 	      for (r = repstart; r < repstop; r++)
-		create_apg0 (nr->apg0[r][world->locus], nr,
-			     &world->atl[r][world->locus]);
+		create_apg0 (nr->apg0[r][locus], nr,
+			     &world->atl[r][locus], locus);
 	    }
 	  else
 	    {
 	      if (kind != PROFILE)
 		{
 		  for (r = repstart; r < repstop; r++)
-		    create_apg0 (nr->apg0[r][world->locus], nr,
-				 &world->atl[r][world->locus]);
-		  interpolate_like (nr, world->locus);
+		    create_apg0 (nr->apg0[r][locus], nr,
+				 &world->atl[r][locus], locus);
+		  interpolate_like (nr, locus);
+		}
+	      else
+		{
+		  for (r = repstart; r < repstop; r++)
+		    create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
 		}
-	      for (r = repstart; r < repstop; r++)
-		create_multiapg0 (nr->apg0[r][world->locus], nr, r,
-				  world->locus);
 	    }
 	}
+    }
+  else				//single locus
+    {
+      if (repkind == SINGLECHAIN)
+	{
+	  for (r = repstart; r < repstop; r++)
+	    create_apg0 (nr->apg0[r][world->locus], nr,
+			 &world->atl[r][world->locus], world->locus);
+	}
+      else
+	{
+	  if (kind != PROFILE)
+	    {
+	      for (r = repstart; r < repstop; r++)
+		create_apg0 (nr->apg0[r][world->locus], nr,
+			     &world->atl[r][world->locus], world->locus);
+	      interpolate_like (nr, world->locus);
+	    }
+	  for (r = repstart; r < repstop; r++)
+	    create_multiapg0 (nr->apg0[r][world->locus], nr, r, world->locus);
+	}
+    }
 }
 
 void
@@ -1210,7 +1239,7 @@ report_broyden (double newL, double normd, long trials,
     {
       if (boolgamma)
 	fprintf (logfile, "%i:%li> Log(L)=%f Norm=%f Alpha=%f Theta_1=%f\n",
-		 myID,trials, newL, normd, alpha, theta1);
+		 myID, trials, newL, normd, alpha, theta1);
       else
 	fprintf (logfile, "%i:%li> Log(L)=%f Norm=%f Theta_1=%f\n",
 		 myID, trials, newL, normd, theta1);
@@ -1285,9 +1314,10 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
   double *xv;
   double *expxv;
   double *temp;
-  double *tempparam; //just pointer into temp
-  double *templparam;//just pointer into temp
+  double *tempparam;		//just pointer into temp
+  double *templparam;		//just pointer into temp
   helper_fmt helper;
+
   //  long reset_z = 0;
   helper.boolgamma = world->locus == world->loci ? wopt->gamma : FALSE;
   if (helper.boolgamma)
@@ -1297,9 +1327,9 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
   doublevec1d (&delta, nnn);
   doublevec1d (&gama, nnn);
   doublevec1d (&xv, nnn + 1);
-    doublevec1d (&temp, 2*(nnn+1));
+  doublevec1d (&temp, 2 * (nnn + 1));
   tempparam = temp;
-  templparam = temp+nnn+1;
+  templparam = temp + nnn + 1;
   helper.xv = xv;
   //  expxv = xv + nnn;
   //memcpy(expxv,param,sizeof(double)*nnn);
@@ -1318,15 +1348,23 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
   nnn = multilocus_gamma_adjust (helper.multilocus, helper.boolgamma,
 				 world, repstart, repstop);
   nn = nnn;
+//if(helper.boolgamma)
+//{
+ // save_a = nr->world->options->custm[nr->world->numpop2];
+  // world->options->custm[nr->world->numpop2]='c';
+  // world->options->custm2[nr->world->numpop2]='c';
+//}
   profile_setup (nr->profilenum, nr->profiles, xv, nr->values, &nnn);
   fill_profile_index (nr);
-
+  helper.lamda = 0.; 
+  helper.dv = dv;
   calc_loci_param (nr, xv, xv0, gxv, 0., nnn);
   set_expparam (expxv, xv, nn);
   SETUPPARAM0 (world, nr, world->repkind, repstart, repstop,
-		    world->loci, analystype, helper.multilocus);
+	world->loci, analystype, helper.multilocus);
   fill_helper (&helper, expxv, xv, world, nr);
   oldL = CALCLIKE (&helper, expxv, xv);
+  //  oldL= -DBL_MAX;
   fill_helper (&helper, expxv, xv, world, nr);
   CALCGRADIENT (nr, &helper, gxv);
   memcpy (gxv0, gxv, sizeof (double) * nnn);
@@ -1341,26 +1379,10 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
 #endif
       newL = -DBL_MAX;
       if (helper.boolgamma)
-	    	     lamda = line_search(dv, gxv, psilo, &helper, oldL, tempparam, templparam); 
-//	lamda = 10.;		
-       else
-	  {
-	    //if(analystype==MULTILOCUS)
-	    	     lamda = line_search(dv, gxv, psilo, &helper, oldL, tempparam, templparam); 
-	    //{
-	     //	     lamda = calc_line (&helper, -10., 0.1, 10., psilo, tempparam, templparam);
-	     //	      printf("*%li> l1=%f ",trials, lamda);
-	    //lamda = line_search(psi, &helper, oldL, tempparam, templparam);
-	      //printf("l2=%f\n",lamda);
-	      //}
-	      //else
-	      // {
-	      //lamda = calc_line (&helper, -10., 0.1, 10., psi, tempparam, templparam);
-	      // printf("%i - %li> l1=%f\n ",myID, trials, lamda);
-	      //lamda = line_search(psi, &helper, oldL, tempparam, templparam);
-	      //printf("l2=%f\n",lamda);
-	      //}
-	}
+	lamda = line_search (dv, gxv, psilo, &helper, oldL, tempparam, templparam);
+      else
+	  lamda =	    line_search (dv, gxv, psilo, &helper, oldL, tempparam, templparam);
+	helper.lamda = lamda;
       while ((newL <= oldL || isnan (newL) || newL <= -DBL_MAX) &&
 	     fabs (lamda) > 10. * DBL_EPSILON)
 	{
@@ -1374,8 +1396,8 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
 #ifdef LAGUERRE
       if (nr->world->locus >= nr->world->loci && nr->world->options->gamma)
 	{
-	  initgammacat (nr->categs, expxv[nr->numpop2], expxv[0],
-			nr->rate, nr->probcat);
+//	   initgammacat (nr->categs, expxv[nr->numpop2], expxv[0],
+//				nr->rate, nr->probcat);
 	  if (fabs (oldL - newL) < 1e-9)
 	    lamda = 0.;
 	}
@@ -1404,7 +1426,7 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
 	  memcpy (dv, gxv, sizeof (double) * nnn);
 	  continue;
 	}
-	//swap(gxv0,gxv);
+      //swap(gxv0,gxv);
       memcpy (gxv0, gxv, sizeof (double) * nnn);
       //calc_loci_param (nr, xv, xv0, dv, lamda * two, nn);
       //set_expparam(expxv,xv,nn);
@@ -1417,6 +1439,12 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
       memcpy (xv0, xv, sizeof (double) * nn);
     }
 /* end maximizer cycle ------------------------------------*/
+/*if(helper.boolgamma)
+{
+   world->options->custm[nr->world->numpop2]=save_a;
+   world->options->custm2[nr->world->numpop2]=save_a;
+}*/
+
   finish_broyden (newL, normd, trials, world, nr, expxv, nn,
 		  analystype, repkind);
   memcpy (param, expxv, sizeof (double) * nn);
@@ -1430,7 +1458,8 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
   free (xv0);
   free (xv);
   free (expxv);
- free(temp);
+  free (temp);
+  fflush (stderr);
   return trials;
 }
 
@@ -1443,7 +1472,7 @@ finish_broyden (double newL, double normd, long trials,
 
   timearchive_fmt **tyme = world->atl;
   memcpy (world->param0, expxv, sizeof (double) * nn);
-  //correct_values (world, nr);	// resets huge thetas to average
+  //correct_values (world, nr); // resets huge thetas to average
 
   if (world->options->verbose)
     fprintf (stdout, "\n");
@@ -1451,8 +1480,8 @@ finish_broyden (double newL, double normd, long trials,
   switch (analystype)
     {
     case MULTILOCUS:
-  //    tyme[0][loci].param = (double *) realloc (tyme[0][loci].param,
-//						sizeof (double) * nn);
+      //    tyme[0][loci].param = (double *) realloc (tyme[0][loci].param,
+//                                              sizeof (double) * nn);
       tyme[0][loci].param_like = newL;
       tyme[0][loci].normd = normd;
       tyme[0][loci].trials = trials;
@@ -1566,10 +1595,11 @@ fill_helper (helper_fmt * helper, double *param, double *lparam,
       if (alpha <= 0.0)
 	error ("no no! alpha=0\n");
       denom = LGAMMA (alpha) + log (theta1 / alpha) * alpha;
+  //  denom = LGAMMA (alpha) + log (1. / alpha) * alpha;
     }
-  if(nr->lparam!=lparam) 
+  if (nr->lparam != lparam)
     memcpy (nr->lparam, lparam, sizeof (double) * nr->partsize);
-  if(nr->param!=param) 
+  if (nr->param != param)
     memcpy (nr->param, param, sizeof (double) * nr->partsize);
 
   helper->nr = nr;
