@@ -39,7 +39,8 @@ extern void read_distance_fromfile (FILE * dfile, long tips, long nmlength,
 extern void read_geofile (data_fmt * data, option_fmt * options, long numpop);
 // used in MPI context
 extern void init_data_structure1 (data_fmt ** data, option_fmt * options);
-extern void init_data_structure2 (data_fmt ** data, option_fmt * options, long pop);
+extern void init_data_structure2 (data_fmt ** data, option_fmt * options,
+				  long pop);
 extern void init_data_structure3 (data_fmt * data);
 extern void create_alleles (data_fmt * data);
 extern void set_numind (data_fmt * data);
