@@ -12,7 +12,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: fst.c,v 1.17 2001/06/02 21:40:21 beerli Exp $
+$Id: fst.c,v 1.18 2001/07/25 19:27:23 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -28,7 +28,8 @@ void fst_type (char type);
 
 void calc_fst (world_fmt * world, data_fmt * data);
 /* private functions */
-void frequencies (double ***f, double **f2, char *****data, long numpop, long **numind, long loci);
+void frequencies (double ***f, double **f2, char *****data, long numpop,
+		  long **numind, long loci);
 void calc_fw (double ***f, long numpop, long locus, double *fw);
 void calc_fb (double ***f, long numpop, long locus, double *fb);
 void calc_seq_fw (data_fmt * data, long numpop, long locus, double *fw);
@@ -47,7 +48,8 @@ fst_type (char type)
   switch (type)
     {
     case 'T':
-      solveNm = (void (*)(double *, double *, long, double *)) solveNm_vartheta;
+      solveNm =
+	(void (*)(double *, double *, long, double *)) solveNm_vartheta;
       break;
     case 'M':
       solveNm = (void (*)(double *, double *, long, double *)) solveNm_varm;
@@ -75,7 +77,7 @@ calc_fst (world_fmt * world, data_fmt * data)
     {
       fst_type ('S');
     }
-  if (!strchr(SEQUENCETYPES,world->options->datatype))
+  if (!strchr (SEQUENCETYPES, world->options->datatype))
     {
       fstfreq = (double ***) calloc (1, sizeof (double **) * world->numpop);
       fstfreq2 = (double **) calloc (1, sizeof (double *) * world->loci);
@@ -83,15 +85,18 @@ calc_fst (world_fmt * world, data_fmt * data)
 	fstfreq2[locus] = (double *) calloc (1, sizeof (double) * 255);
       for (pop = 0; pop < world->numpop; pop++)
 	{
-	  fstfreq[pop] = (double **) calloc (1, sizeof (double *) * world->loci);
+	  fstfreq[pop] =
+	    (double **) calloc (1, sizeof (double *) * world->loci);
 	  for (locus = 0; locus < world->loci; locus++)
-	    fstfreq[pop][locus] = (double *) calloc (1, sizeof (double) * 255);
+	    fstfreq[pop][locus] =
+	      (double *) calloc (1, sizeof (double) * 255);
 	}
-      frequencies (fstfreq, fstfreq2, data->yy, world->numpop, data->numind, world->loci);
+      frequencies (fstfreq, fstfreq2, data->yy, world->numpop, data->numind,
+		   world->loci);
     }
   for (locus = 0; locus < world->loci; locus++)
     {
-      if (strchr(SEQUENCETYPES,world->options->datatype))
+      if (strchr (SEQUENCETYPES, world->options->datatype))
 	{
 	  calc_seq_fw (data, world->numpop, locus, fw);
 	  calc_seq_fb (data, world->numpop, locus, fb);
@@ -123,7 +128,7 @@ calc_fst (world_fmt * world, data_fmt * data)
     }
 
   (*solveNm) (sumfw, sumfb, world->numpop, world->fstparam[world->loci]);
-  if (!strchr(SEQUENCETYPES,world->options->datatype))
+  if (!strchr (SEQUENCETYPES, world->options->datatype))
     {
       for (pop = 0; pop < world->numpop; pop++)
 	{
@@ -146,7 +151,8 @@ calc_fst (world_fmt * world, data_fmt * data)
 /*=======================================================*/
 
 void
-frequencies (double ***f, double **f2, char *****data, long numpop, long **numind, long loci)
+frequencies (double ***f, double **f2, char *****data, long numpop,
+	     long **numind, long loci)
 {
   long **buckets, *buckets2;
   long *total, pop, locus, ind, a;
@@ -177,9 +183,11 @@ frequencies (double ***f, double **f2, char *****data, long numpop, long **numin
 	      for (a = 0; a < 255; a++)
 		{
 		  if (total[pop] > 0)
-		    f[pop][locus][a] = (double) buckets[pop][a] / (double) total[pop];
+		    f[pop][locus][a] =
+		      (double) buckets[pop][a] / (double) total[pop];
 		  if (total[0] + total[1] > 0)
-		    f2[locus][a] = (double) buckets2[a] / ((double) total[0] + total[1]);
+		    f2[locus][a] =
+		      (double) buckets2[a] / ((double) total[0] + total[1]);
 		}
 	    }
 	}
@@ -232,7 +240,10 @@ calc_seq_fw (data_fmt * data, long numpop, long locus, double *fw)
   for (pop = 0; pop < numpop; pop++)
     {
       fw[pop] = 0;
-      nn = data->seq->sites[locus] * (data->numind[pop][locus] * data->numind[pop][locus] - data->numind[pop][locus]) / 2.;
+      nn =
+	data->seq->sites[locus] * (data->numind[pop][locus] *
+				   data->numind[pop][locus] -
+				   data->numind[pop][locus]) / 2.;
       for (i = 0; i < data->numind[pop][locus]; i++)
 	{
 	  for (k = i + 1; k < data->numind[pop][locus]; k++)
@@ -240,7 +251,9 @@ calc_seq_fw (data_fmt * data, long numpop, long locus, double *fw)
 	      diff = 0.;
 	      for (j = 0; j < data->seq->sites[locus]; j++)
 		{
-		  diff += (data->yy[pop][i][locus][0][j] != data->yy[pop][k][locus][0][j]);
+		  diff +=
+		    (data->yy[pop][i][locus][0][j] !=
+		     data->yy[pop][k][locus][0][j]);
 		}
 	      if (nn > 0)
 		fw[pop] += diff / nn;
@@ -262,7 +275,9 @@ calc_seq_fb (data_fmt * data, long numpop, long locus, double *fb)
       for (p2 = p1 + 1; p2 < numpop; p2++)
 	{
 	  temp = 0.;
-	  nn = (double) data->seq->sites[locus] * data->numind[p1][locus] * data->numind[p2][locus];
+	  nn =
+	    (double) data->seq->sites[locus] * data->numind[p1][locus] *
+	    data->numind[p2][locus];
 	  for (i = 0; i < data->numind[p1][locus]; i++)
 	    {
 	      for (k = 0; k < data->numind[p2][locus]; k++)
@@ -270,7 +285,9 @@ calc_seq_fb (data_fmt * data, long numpop, long locus, double *fb)
 		  diff = 0.;
 		  for (j = 0; j < data->seq->sites[locus]; j++)
 		    {
-		      diff += (data->yy[p1][i][locus][0][j] != data->yy[p2][k][locus][0][j]);
+		      diff +=
+			(data->yy[p1][i][locus][0][j] !=
+			 data->yy[p2][k][locus][0][j]);
 		    }
 		  if (nn > 0)
 		    temp += diff / nn;
@@ -309,12 +326,14 @@ solveNm_varm (double *fw, double *fb, long numpop, double *params)
   if (denom == 0.0)
     params[offset] = -999;
   else
-    params[offset] = (2. * fb[0] - fw[0] - 2. * fb[0] * fw[0] + fw[1]) / denom;
+    params[offset] =
+      (2. * fb[0] - fw[0] - 2. * fb[0] * fw[0] + fw[1]) / denom;
   denom = ((fb[0] - fw[1]) * (-2. + fw[0] + fw[1]));
   if (denom == 0.0)
     params[offset + 1] = -999;
   else
-    params[offset + 1] = (2. * fb[0] - fw[1] - 2. * fb[0] * fw[1] + fw[0]) / denom;
+    params[offset + 1] =
+      (2. * fb[0] - fw[1] - 2. * fb[0] * fw[1] + fw[0]) / denom;
   for (i = 0; i < offset2; i++)
     {
       if (params[i] < 0.)
