@@ -6,42 +6,204 @@
 #include "migration.h"
 #include "broyden.h"
 #include "combroyden.h"
+#include "laguerre.h"
 
-
-double gamma_loci_like (nr_fmt * nr, double *oparam,
+double gamma_loci_like (helper_fmt *helper, double *oparam,
 			double *olparam, double denom);
 double gamma_locus_like (nr_fmt * nr, double *oparam,
-			double *olparam, double denom, long locus);
+			 double *olparam, double denom, long locus);
 double loggf (double r, double alpha, double theta1);
 void gamma_loci_derivative (helper_fmt * helper);
 void gamma_locus_derivative (helper_fmt * helper, long locus);
-double gamma_theta1_derivative (double theta, double *param, nr_fmt * nr,
-				long locus, int *sign);
-double gamma_other_derivative (long which, double theta, double *param,
-			       nr_fmt * nr, long locus, int *sign);
-double gamma_alpha_derivative (double theta, double *param, nr_fmt * nr,
-			       long locus, int *sign);
+//double gamma_theta1_derivative (double theta, double *param, nr_fmt * nr,
+//                              long locus, int *sign);
+//double gamma_other_derivative (long which, double theta, double *param,
+//                             nr_fmt * nr, long locus, int *sign);
+//double gamma_alpha_derivative (double theta, double *param, nr_fmt * nr,
+//                             long locus, int *sign);
 void gamma_parts_gradient (double x, double *param, nr_fmt * nr, long locus);
 double dt_locus_gsum (long which, double x, double *param, nr_fmt * nr,
 		      timearchive_fmt ** atl, long locus);
 
 
 double
-gamma_loci_like (nr_fmt * nr, double *oparam, double *olparam, double denom)
+gamma_loci_like(helper_fmt *helper, double *oparam, double *olparam, double denom)
 {
   long locus;
   double summ = 0.0;
+  nr_fmt *nr = helper->nr;
   for (locus = 0; locus < nr->world->loci; locus++)
     {
       if (nr->skiploci[locus])
 	continue;
       nr->locilikes[locus] =
-	gamma_locus_like(nr, oparam, olparam, denom, locus);
+	gamma_locus_like (nr, oparam, olparam, denom, locus);
       summ += nr->locilikes[locus];
     }
   return summ;
 }
 
+
+double find_gamma_summ(double la, double theta1, nr_fmt *nr, double *oparam, double *olparam, 
+	long locus, helper_fmt *helper);
+
+
+double
+gamma_loci_like_iterative(helper_fmt * helper, double *oparam, double *olparam, double denom)
+{
+// hack to get around the problem of not being able to get a clean derivative of alpha
+// uses a simple maxima finder for alpha
+  long locus;
+  double fa = 0.0;
+  double fla, fha;
+  double la  = -10;
+  double ha = +4;
+  double a;
+  double fm, m;
+  double theta1 = helper->nr->param[0];
+  nr_fmt *nr = helper->nr;
+  char save_a = nr->world->options->custm[nr->world->numpop2];
+//  if(save_a == 'c')
+ // {
+//	return  gamma_loci_like_old (helper, oparam, olparam, denom);
+  // }
+   nr->world->options->custm[nr->world->numpop2]='c';
+   nr->world->options->custm2[nr->world->numpop2]='c';
+  fla = find_gamma_summ( la,  theta1, nr,  oparam, olparam,  locus, helper);
+  fha = find_gamma_summ( ha,  theta1, nr,  oparam, olparam,  locus, helper);  
+  a = (ha + la)/2.;
+  fa = find_gamma_summ( a,  theta1, nr,  oparam, olparam,  locus, helper);
+  m = (la + a) / 2.;	
+  fm = find_gamma_summ( m,  theta1, nr,  oparam, olparam,  locus, helper);
+  while(fabs(fla-fha)> EPSILON && fabs(ha-la) > EPSILON)
+  {
+	if(fm < fa)
+	{
+		fla = fm;
+		la = m;
+	}
+	else
+	{
+		fha = fa;
+		ha  = a;
+		a = m;
+		fa = fm;
+	}
+	m = (ha + la)/2.;
+	fa = find_gamma_summ( m,  theta1, nr,  oparam, olparam,  locus, helper);
+
+  }
+  nr->param[nr->numpop2] = exp(m);
+  nr->lparam[nr->numpop2] = m;
+  nr->world->options->custm[nr->world->numpop2]=save_a;
+  nr->world->options->custm2[nr->world->numpop2]=save_a;
+  return fa;
+}
+
+
+double
+gamma_loci_like_new_notworking(helper_fmt * helper, double *oparam, double *olparam, double denom)
+{
+  long locus;
+  long trials;
+  double logalpha;
+  double psiabc;
+  double theta1 = helper->nr->param[0];
+  nr_fmt *nr = helper->nr;
+  char save_a = nr->world->options->custm[nr->world->numpop2];
+
+  double a, b, c,  m=0.5;
+  double la, lb, lc, ll, ql;
+  //double lm;
+  a= 0.00000000001;
+  b= 1.0;
+  c=2.0;
+   nr->world->options->custm[nr->world->numpop2]='c';
+   nr->world->options->custm2[nr->world->numpop2]='c';
+  la = find_gamma_summ( a,  theta1, nr,  oparam, olparam,  locus, helper);
+  lb = find_gamma_summ( b,  theta1, nr,  oparam, olparam,  locus, helper);  
+  lc = find_gamma_summ( c,  theta1, nr,  oparam, olparam,  locus, helper);
+  
+  while(trials++ < NTRIALS)
+  {
+       logalpha =
+	(c * c * (lb - la) + b * b * (la - lc) +
+	 a * a * (lc - lb)) / (2. * (b * la - c * la - a * lb + c * lb +
+				     a * lc - b * lc));
+      psiabc = ((la - lb) / (-a + b) + (la - lc) / (a - c)) / (-b + c);
+      if ((psiabc <= 0.0) || (logalpha >= m))
+	{
+	  if (a == m)
+	  {
+		ll = la;
+		logalpha = m;
+		break;
+	  }
+	  if (b == m)
+	  {
+		ll = lb;
+		logalpha = m;
+		break;
+	  }
+	  if (c == m)
+	  {
+		ll = lc;
+		logalpha = m;
+		break;
+	  }		
+	ll = find_gamma_summ( m,  theta1, nr,  oparam, olparam,  locus, helper);
+	replace_with (m, &a, &b, &c, m, &la, &lb, &lc, ll);
+      }
+      ll = find_gamma_summ( logalpha,  theta1, nr,  oparam, olparam,  locus, helper);
+	ql = quadratic_lamda (logalpha, a, b, c, la, lb, lc);
+      if ((fabs (ll - MYMIN3 (la, lb, lc)) <= BIGEPSILON)
+	  || (fabs (ll - ql) <= BIGEPSILON))
+        {
+	       break;
+	}	
+      else
+	{
+	  replace_with (1., &a, &b, &c, logalpha, &la, &lb, &lc,
+			ll);
+	  m = MYMAX3 (a, b, c);
+	}
+    }
+  nr->param[nr->numpop2] = exp(logalpha);
+  nr->lparam[nr->numpop2] = logalpha;
+  nr->world->options->custm[nr->world->numpop2]=save_a;
+  nr->world->options->custm2[nr->world->numpop2]=save_a;
+  return ll;
+}
+
+double find_gamma_summ(double lla, double theta1, nr_fmt *nr, double *oparam, double *olparam, 
+	long locus, helper_fmt *helper)
+{
+	double la = exp(lla);
+	double denom =  -LGAMMA(la) - la * log(theta1/la);
+	double summ=0.0;
+	double so = oparam[nr->numpop2];
+	double slo = olparam[nr->numpop2];
+	oparam[nr->numpop2] = la;
+	olparam[nr->numpop2] = lla;
+      if (olparam[nr->numpop2] > 9.903487553)
+	{  
+		olparam[nr->numpop2] = 9.903487553;
+	}
+		initgammacat (nr->categs, oparam[nr->numpop2],1./* EXP (lparam[0])*/,
+		    nr->rate, nr->probcat);
+	//calc_loci_param (nr, olparam, oparam, helper->dv, helper->lamda, nr->partsize);
+	for (locus = 0; locus < nr->world->loci; locus++)
+	{
+		if (nr->skiploci[locus])
+			continue;
+		nr->locilikes[locus] = gamma_locus_like (nr, oparam, olparam, denom, locus);
+		summ += nr->locilikes[locus];
+	}
+	oparam[nr->numpop2] = so;
+	olparam[nr->numpop2] = slo;
+	return summ;
+}
+
 double
 gamma_locus_like (nr_fmt * nr, double *oparam, double *olparam, double denom,
 		  long locus)
@@ -93,14 +255,14 @@ gamma_loci_difference (helper_fmt * helper)
   memset (nr->d, 0, size * sizeof (double));
   setdoublevec1d (&lparam, helper->xv, size);
   setdoublevec1d (&param, helper->expxv, size);
-  mle = gamma_loci_like (nr, param, lparam, helper->weight);
+  mle = gamma_loci_like (helper, param, lparam, helper->weight);
   for (i = 0; i < size; i++)
     {
       memcpy (param, expxv, sizeof (double) * size);
       memcpy (lparam, xv, sizeof (double) * size);
       param1 = (param[i] += epsilon);
       lparam[i] = log (param[i]);
-      high = gamma_loci_like (nr, param, lparam, helper->weight);
+      high = gamma_loci_like (helper, param, lparam, helper->weight);
       param[i] -= 2. * epsilon;
       if (param[i] < 0.0)
 	{
@@ -110,7 +272,7 @@ gamma_loci_difference (helper_fmt * helper)
       else
 	{
 	  lparam[i] = log (param[i]);
-	  low = gamma_loci_like (nr, param, lparam, helper->weight);
+	  low = gamma_loci_like (helper, param, lparam, helper->weight);
 	}
       nr->d[i] = (high - low) / (param1 - param[i]);
     }
@@ -173,13 +335,13 @@ gamma_locus_derivative (helper_fmt * helper, long locus)
       set_gamma_param (nr->param, helper->expxv,
 		       nr->lparam, helper->xv, rate, nr);
       ll = nr->probcat[r] + calc_locus_like (nr, nr->param, nr->lparam, locus);
-      ll += -rate * alpha / theta1 + lograte * (alpha - 1.) - denom;
-      //summll[r] = ll;
-      //if(ll>summllmax)
-      //summllmax = ll;
+	ll +=  -rate * alpha / theta1 + lograte * (alpha - 1.);
+      //ll +=  -rate * alpha + lograte * (alpha - 1.);
       gamma_parts_gradient (rate, helper->expxv, nr, locus);	//changes nr->parts
       //first of the derivatives: theta1
-      tmp = rate * alpha / (theta1 * theta1) + nr->parts[0];
+//     tmp =  nr->parts[0];
+	      tmp = rate * alpha / (theta1 * theta1) + nr->parts[0];
+
       stemp[0][r] = tmp < 0. ? -1 : 1;
       temp[0][r] = ll + log (fabs (tmp));
       if (tempmax[0] < temp[0][r])
@@ -193,37 +355,36 @@ gamma_locus_derivative (helper_fmt * helper, long locus)
 	    tempmax[i] = temp[i][r];
 	}
       // last derivative: alpha
-      tmp = -rate / theta1 + lograte;
+	tmp = -rate/theta1 + lograte;
+      //tmp = - theta1*lograte + rate;
       stemp[i][r] = tmp < 0. ? -1 : 1;
       temp[i][r] = ll + log (fabs (tmp));
       if (tempmax[i] < temp[i][r])
 	tempmax[i] = temp[i][r];
     }
-  //for (r=0;r<GAMMA_INTERVALS;r++)
-  //  {
-  //    summllsum += EXP (summll[r] - summllmax);
-  //  }
-  //summllsum = log(summllsum) + summllmax; 
   z = 0;
   for (ii = 0; ii < nr->partsize - nr->profilenum; ii++)
     {
       i = (nr->profilenum > 0) ? nr->indeks[z++] : ii;
       sumi = 0;
-
+   //   denom = -LGAMMA(alpha) - alpha * log(1./alpha);
+         denom = -LGAMMA(alpha) - alpha * log(theta1/alpha);
       for (r = 0; r < GAMMA_INTERVALS; r++)
-	sumi += ((double) stemp[i][r]) * EXP (temp[i][r] - tempmax[i]);
+	sumi +=
+	  ((double) stemp[i][r]) * EXP (temp[i][r] -
+					tempmax[i]  +  denom);
       if (i == 0)
 	{
-	  //  printf("summll=%f locilikes[%li]=%f\n",summllsum,locus,nr->locilikes[locus]);
 	  sumi =
+//	    sumi * EXP (tempmax[i] - nr->locilikes[locus]);
 	    sumi * EXP (tempmax[i] - nr->locilikes[locus]) - alpha / theta1;
 	}
       else
 	{
 	  if (i == nr->numpop2)
 	    {
-	      sumi = sumi * EXP (tempmax[i] - nr->locilikes[locus])
-		- polygamma (0, alpha) - log (theta1 / alpha) + 1.;
+			sumi = sumi *(EXP (tempmax[i] - nr->locilikes[locus]))
+						- polygamma (0, alpha) - log (theta1 / alpha) +1.;
 	    }
 	  else
 	    sumi = sumi * EXP (tempmax[i] - nr->locilikes[locus]);
