@@ -7,10 +7,11 @@
 // and for its derivatives
 #include "migration.h"
 
-extern double gamma_loci_like (nr_fmt * nr, double *oparam,
-			       double *olparam,  double denom);
-extern double gamma_locus_like (nr_fmt * nr, double *oparam, double *olparam, double denom,
-				long locus);
+extern double gamma_loci_like (helper_fmt * helper, double *oparam,
+			       double *olparam, double denom);
+extern double gamma_locus_like (nr_fmt * nr, double *oparam, double *olparam,
+				double denom, long locus);
 extern void gamma_loci_derivative (helper_fmt * helper);
+extern void gamma_locus_derivative (helper_fmt * helper, long locus);
 extern void gamma_loci_difference (helper_fmt * helper);
 #endif
