@@ -7,7 +7,7 @@ Peter Beerli 2000
 
 Copyright 2001 Peter Beerli and Joseph Felsenstein
 
-$Id: heating.h,v 1.6 2001/06/02 21:40:21 beerli Exp $
+$Id: heating.h,v 1.7 2001/07/25 19:27:23 beerli Exp $
 
 */
 
@@ -23,7 +23,7 @@ typedef struct tpool_work
 }
 tpool_work_t;
 
-typedef struct tpool
+typedef struct _tpool_t
 {
   int num_threads;
   int max_queue_size;
@@ -42,10 +42,14 @@ typedef struct tpool
   int shutdown;
   int done;
 }
- *tpool_t;
+_tpool_t;
 
-extern void tpool_init (tpool_t * tpoolp, int num_worker_threads, int max_queue_size, int do_not_block_when_full);
-extern void fill_tpool (tpool_t tpool, world_fmt ** universe, int universe_size);
+typedef _tpool_t *tpool_t;
+
+extern void tpool_init (tpool_t * tpoolp, int num_worker_threads,
+			int max_queue_size, int do_not_block_when_full);
+extern void fill_tpool (tpool_t tpool, world_fmt ** universe,
+			int universe_size);
 extern void wait_tpool (tpool_t tpoolp, int usize);
 extern int tpool_destroy (tpool_t tpool, int finish);
 extern int tpool_synchronize (tpool_t tpool, int finish);
