@@ -48,7 +48,7 @@ create_multiapg0 (double *apg0, nr_fmt * nr, long rep, long locus)
 	  tmp[r] = -reps +
 	    probG (nr->world->atl[r][locus].param0,
 		   nr->world->atl[r][locus].lparam0,
-		   &nr->world->atl[rep][locus].tl[g], nr)
+		   &nr->world->atl[rep][locus].tl[g], nr, locus)
 	    - (nr->world->chainlikes[locus][r]);
 	  if (tmp[r] > tmpmax)
 	    tmpmax = tmp[r];
@@ -134,11 +134,8 @@ interpolate_like (nr_fmt * nr, long locus)
 		  delta, z);
 	}
     }
-  free(newlike);
-  free(diff);
-  free(oldiff);
-  free(lparam);
+  free (newlike);
+  free (diff);
+  free (oldiff);
+  free (lparam);
 }
-
-
-
