@@ -70,6 +70,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
   double *param0;
   double *param1;
   long *maxwhich;
+  long nparam;
   long maxnum = 0;
   long rep = !world->options->replicate ? 0 :
     (world->options->replicatenum == 0 ?
@@ -91,7 +92,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
 	for (r = 0; r < repstop; r++)
 	  create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
       else
-	create_apg0 (nr->apg0[0][locus], nr, &world->atl[0][locus]);
+	create_apg0 (nr->apg0[0][locus], nr, &world->atl[0][locus], locus);
     }
   if (world->loci > 1)
     {
@@ -103,13 +104,14 @@ print_lratio_test (world_fmt * world, long *Gmax)
       locus = 0;
     }
   PAGEFEEDWORLD;
+  nparam = world->options->gamma ? world->numpop2 + 1 : world->numpop2;
   for (c = 0; c < world->options->lratio->counter; c++)
     {
       header = (c == 0) ? HEADER : NOHEADER;
       if (world->options->lratio->data[c].type == MLE)
 	{
 	  memcpy (param1, world->atl[rep][locus].param,
-		  sizeof (double) * world->numpop2);
+		  sizeof (double) * nparam);
 	  df = set_test_param (param0,
 			       world->options->lratio->data[c].value1,
 			       world, 0, -1, maxwhich, &maxnum, &zeros);
@@ -191,7 +193,10 @@ test_locus_like (nr_fmt * nr, double *param0, double *param1, long df,
   saveparam0 = (double *) malloc (sizeof (double) * (world->numpop2 + 1));
   memcpy (saveparam0, param0, sizeof (double) * (world->numpop2 + 1));
   nr->skiploci = world->data->skiploci;
-  elem = nr->numpop2 = world->numpop2;
+  if (world->options->gamma)
+    elem = (nr->numpop2 = world->numpop2) + 1;
+  else
+    elem = nr->numpop2 = world->numpop2;
   nr->numpop = world->numpop;
   if (maxnum > 0)
     {
@@ -484,13 +489,14 @@ set_test_param (double *param, char *strp, world_fmt * world, long lrline,
   long numpop = world->numpop;
   char *tmp, *ss, *paramtype;
   double *meanparam, mean;
+  long elem = world->options->gamma ? world->numpop2 + 1 : world->numpop2;
   long repstop = !world->options->replicate ? 0 :
     (world->options->replicatenum == 0 ?
      world->options->lchains : world->options->replicatenum);
   *zeros = 0;
   ss = (char *) calloc (1, sizeof (char) * LINESIZE);
   tmp = (char *) calloc (1, sizeof (char) * LINESIZE);
-  paramtype = (char *) calloc (1, sizeof (char) * world->numpop2);
+  paramtype = (char *) calloc (1, sizeof (char) * elem);
 
   *maxnum = 0;
   strcpy (ss, strp);
