@@ -53,18 +53,18 @@ $Id: main.c,v 1.76 2001/09/07 23:56:13 beerli Exp $
 /* GLOBAL VARIABLES +++++++++++++++++++++++++++++++++++++*/
 int myID;			/* used if MPI is running otherwise == 0       */
 int allID;
-int color; /* either 1 or MPI_UNDEFINED */
+int color;			/* either 1 or MPI_UNDEFINED */
 int numcpu;			/* used if MPI is running otherwise == 1     */
 int numlocicpu;
 int locidone;			/* used in MPI workers */
 //MPI_Comm       comm_all_worlds;
 #ifdef MPI
-MPI_Comm       comm_world;
+MPI_Comm comm_world;
 MPI_Comm comm_all_worlds;
 MPI_Comm comm_otherworld;
 #endif
 #ifdef SLOWNET
-int profiledone;  /* used in MPI workers in profiles on slow networks */
+int profiledone;		/* used in MPI workers in profiles on slow networks */
 #endif
 #ifdef PTHREADS
 tpool_t heating_pool;
@@ -176,7 +176,7 @@ main (int argc, char **argv)
   char *this_string;
   char type = 's';
   data_fmt *data;
-  //  int i;
+//unused in all compile variants?  int i;
   int usize = HEATED_CHAIN_NUM;
   long Gmax = 0;
   long outfilepos = 0;
@@ -189,14 +189,14 @@ main (int argc, char **argv)
 //  comm_all_worlds = MPI_COMM_WORLD;
 //MPI_Comm_size (comm_all_worlds, &numcpu);
 //MPI_Comm_rank (comm_all_worlds, &allID);
-comm_world = MPI_COMM_WORLD;
-MPI_Comm_size (comm_world, &numcpu);
-MPI_Comm_rank (comm_world, &allID);
+  comm_world = MPI_COMM_WORLD;
+  MPI_Comm_size (comm_world, &numcpu);
+  MPI_Comm_rank (comm_world, &allID);
 
-myID = allID;
+  myID = allID;
 #ifdef SLOWNET
-	profiledone=0;
-	which_calc_like(SINGLELOCUS);
+  profiledone = 0;
+  which_calc_like (SINGLELOCUS);
 #endif
 #else
   myID = MASTER;
@@ -271,6 +271,9 @@ myID = allID;
     {
 #endif
       print_list (EARTH, options, data);
+      if (EARTH->options->gamma)
+	print_alpha_curve (EARTH, EARTH->atl, &Gmax);
+//	print_cov(EARTH, EARTH->numpop, EARTH->loci, EARTH->cov); 
       fflush (EARTH->outfile);
 #ifdef MPI
     }
@@ -302,11 +305,12 @@ myID = allID;
     analyze_uep (EARTH);
 #endif
   /* profile tables --------------------------------------------- */
-#ifdef SLOWNET			/*DOES NOT WORK YET */
+#ifdef SLOWNET		
   // if there are many loci but only few parameters to estimate
-  // this will be still slow and saturating the network
+  // this will be still slow and therefore saturating the network
   // with parameter requests may still be the better solution
-  which_calc_like(PROFILE);
+  // for some -> compile using make mpi instead make mpis
+  which_calc_like (PROFILE);
   if (myID == MASTER)
     {
       mpi_send_stop (EARTH);	// stop workers
@@ -335,7 +339,7 @@ myID = allID;
 #ifndef SLOWNET
   mpi_send_stop (EARTH);	// stop workers
   //printf("%i> at barrier in slownet-main before finalize\n",myID);
-  MPI_Barrier(comm_all_worlds);
+  MPI_Barrier (comm_all_worlds);
 #endif
   MPI_Finalize ();
 #endif
@@ -364,9 +368,10 @@ combine_loci (char type, option_fmt * options, world_fmt * world, long *Gmax)
 	{
 	  mpi_gmax_master (world, Gmax);
 #endif
-	decide_plot (world->options, world->options->lchains, world->options->lchains, 'l');
-	  estimateParameter (options->replicatenum, *Gmax, world,
-			     options, world->cov[world->loci], 0 /*chain */ ,
+	  decide_plot (world->options, world->options->lchains,
+		       world->options->lchains, 'l');
+	  estimateParameter (options->replicatenum, *Gmax, world, options,
+			     world->cov[world->loci], 0 /*chain */ ,
 			     type, kind, world->repkind);
 #ifdef MPI
 	}
@@ -392,10 +397,10 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 #ifdef MPI
 //int *ranks;
 //MPI_Group worldgroup, locigroup;
- if(myID < data->loci+1)
-	color=1;
-else
-	color = MPI_UNDEFINED;
+  if (myID < data->loci + 1)
+    color = 1;
+  else
+    color = MPI_UNDEFINED;
 #endif
   this_string = (char *) calloc (1024, sizeof (char));
 #ifdef MPI
@@ -404,7 +409,8 @@ else
 #endif
       get_data (data->infile, data, options);
 #ifdef MPI
-      broadcast_data_master(data,options);
+      printf ("%i > finished data reading\n", myID);
+      broadcast_data_master (data, options);
       if (numcpu == 1)
 	{
 	  error
@@ -414,10 +420,10 @@ else
   else
     {
       //get_data (data->infile, data, options);
-	broadcast_data_worker(data,options);  
-    }		
-     MPI_Comm_dup(comm_world, &comm_all_worlds);
-     MPI_Comm_rank(comm_world, &myID);
+      broadcast_data_worker (data, options);
+    }
+  MPI_Comm_dup (comm_world, &comm_all_worlds);
+  MPI_Comm_rank (comm_world, &myID);
 #endif
   set_plot (options);
   init_world (EARTH, data, options);
@@ -452,7 +458,7 @@ else
     }
   else
     {
-		mpi_runloci_worker (universe, usize, options, data,
+      mpi_runloci_worker (universe, usize, options, data,
 			  &heating_pool, maxreplicate, &treefilepos, Gmax);
     }
 #else
@@ -929,11 +935,11 @@ analyze_olddata (world_fmt * world,
 #ifdef MPI
       mpi_runloci_master (world->loci, world->who);
 #else
-      for(locus=0;locus<world->loci;locus++)
+      for (locus = 0; locus < world->loci; locus++)
 	{
 	  if (options->replicate && options->replicatenum > 0)
 	    {
-	      world->locus=locus;
+	      world->locus = locus;
 	      world->repkind = MULTIPLERUN;
 	      estimateParameter (options->replicatenum, Gmax, world, options,
 				 world->cov[locus], 1, 'l',
@@ -959,39 +965,43 @@ profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr)
 #endif
   if (options->profile != NONE)
     {
-	world->buffer = (char *) realloc(world->buffer, LINESIZE*100 * sizeof(char));
+      world->buffer =
+	(char *) realloc (world->buffer, LINESIZE * 100 * sizeof (char));
       if (options->printprofsummary)
 	allocate_profile_percentiles (world);
 #ifdef HAVE_STRFTIME
       time (&world->starttime);
 #endif
 #ifdef SLOWNET
-	mpi_broadcast_results(world);
-	if(myID==MASTER)
+      mpi_broadcast_results (world);
+      if (myID == MASTER)
 	{
-		print_profile_title(world);
-		mpi_profiles_master(world, world->numpop2 + (world->options->gamma ? 1 : 0), world->profilewho);
+	  print_profile_title (world);
+	  mpi_profiles_master (world,
+			       world->numpop2 +
+			       (world->options->gamma ? 1 : 0),
+			       world->profilewho);
 	}
-	else
-		mpi_profiles_worker(world, gmaxptr);
+      else
+	mpi_profiles_worker (world, gmaxptr);
 #else
-	print_profile_title(world);
+      print_profile_title (world);
       for (i = 0; i < world->numpop2 + (world->options->gamma ? 1 : 0); i++)
 	{
-		print_profile_likelihood_driver (i, world, gmaxptr);
-		fprintf(world->outfile,"%s\n\n",world->buffer);
-		world->buffer[0] = '\0';
+	  print_profile_likelihood_driver (i, world, gmaxptr);
+	  fprintf (world->outfile, "%s\n\n", world->buffer);
+	  world->buffer[0] = '\0';
 	}
-#endif			
-    if (myID==MASTER && options->printprofsummary)
+#endif
+      if (myID == MASTER && options->printprofsummary)
 	{
 	  print_profile_percentile (world);
-	  fprintf(world->outfile,"%s\n\n",world->buffer);
-		world->buffer[0] = '\0';	  
+	  fprintf (world->outfile, "%s\n\n", world->buffer);
+	  world->buffer[0] = '\0';
 	  destroy_profile_percentiles (world);
 	}
     }
-	//free(world->buffer);
+  //free(world->buffer);
 }
 
 void
