@@ -1095,7 +1095,8 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
 	{
 	  warning ("migration limit (%li) exceeded: %li\n",
 		   MIGRATION_LIMIT * world->numpop, rm);
-	  warning ("results may be underestimating migration rates for this chain\n");
+	  warning
+	    ("results may be underestimating migration rates for this chain\n");
 	  report = FALSE;
 	  oldg = g;
 	}
@@ -1109,7 +1110,8 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
 		    proposal->world->root->next->back,
 		    proposal->world->data->uepsites);
       proposal->firstuep =
-	first_uep (first, proposal->world->root, proposal->world->data->uepsites);
+	first_uep (first, proposal->world->root,
+		   proposal->world->data->uepsites);
       proposal->ueplikelihood = pseudo_ueplikelihood (world, proposal);
       proposal->likelihood = pseudotreelikelihood (world, proposal);
       //      printf("%s> pl=%f pul=%f\n",proposal->world->name,proposal->likelihood,proposal->ueplikelihood);
@@ -1163,12 +1165,12 @@ eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event)
 {
   static boolean mig_force = TRUE;
   double interval, lines, denom;
-
+  //double rate = proposal->world->options->mu_rates[proposal->world->locus];
   double mm = proposal->mig0list[pop];
   long design0 = proposal->design0list[pop];
   lines = 2.0 * tentry->lineages[pop];
   denom = mm + (lines / proposal->param0[pop]);
-  interval = -(log (RANDUM ())) / denom;
+  interval = (-(log (RANDUM ())) / denom);	// * rate;
   if (lines > 0)
     {
       if ((RANDUM ()) < (mm / denom))
