@@ -1169,8 +1169,10 @@ void
 menuParameters (option_fmt * options)
 {
   char input[LINESIZE], custmexplain[LINESIZE];
+  char *temp;
+  long count = 0;
   long i, j, tt, check = 0, numpop = 0;
-
+  double sum = 0.;
   do
     {
 
@@ -1218,8 +1220,10 @@ menuParameters (option_fmt * options)
 	("\n Gene flow parameter and Mutation rate variation among loci:\n");
       printf ("  3       Use M for the gene flow parameter   %15.15s\n",
 	      options->usem ? "Yes [M=m/mu]" : "No [Theta * M]");
-      printf ("  4       Mutation rate is constant? %s\n",
-	      !options->gamma ? "Yes" : "No, varying");
+      printf ("  4       Mutation rate is  %s\n",
+	      !options->gamma ? (options->
+				 murates ? "Varying" : "Constant") :
+	      "Estimated (Gamma)");
       if (options->migrguess == FST || options->thetaguess == FST)
 	{
 	  printf ("\n  FST-Calculation (for start value):\n");
@@ -1373,7 +1377,69 @@ menuParameters (option_fmt * options)
 
 	  break;
 	case '4':
-	  options->gamma = !options->gamma;
+	  printf ("Mutation rate among loci\n");
+	  printf
+	    ("(C)onstant    All loci have the same mutation rate [default]\n");
+	  printf
+	    ("(E)stimated  Mutation rates are drawn from a Gamma distribution\n");
+	  if (options->gamma)
+	    printf ("                   with Shape parameter alpha=%f\n",
+		    options->alphavalue);
+	  printf ("(V)arying     Mutation rates are different among loci\n");
+	  FGETS (input, LINESIZE, stdin);
+	  switch (uppercase (input[0]))
+	    {
+	    case 'E':
+	      options->gamma = TRUE;
+	      options->murates = FALSE;
+	      break;
+	    case 'V':
+	      printf
+		("Enter the number of loci and a rate for each of them\n[the rates are normalized to average to 1.0]\n");
+	      FGETS (input, LINESIZE, stdin);
+	      temp = strtok (input, " ;,;\n");
+	      if (temp == NULL)
+		{
+		  options->murates = FALSE;
+		  options->gamma = FALSE;
+		}
+	      else
+		{
+		  options->gamma = FALSE;
+		  options->murates = TRUE;
+		  options->muloci = atol (temp);
+		  options->mu_rates =
+		    (double *) realloc (options->mu_rates,
+					sizeof (double) * options->muloci);
+		  sum = 0.;
+		  count = 0;
+		  while (temp != NULL)
+		    {
+		      temp = strtok (NULL, " ;,;\n");
+		      if (temp == NULL)
+			break;
+		      options->mu_rates[count] = atof (temp);
+		      sum += options->mu_rates[count];
+		      count++;
+		    }
+		  for (i = count; i < options->muloci; i++)
+		    {
+		      options->mu_rates[i] = options->mu_rates[count - 1];
+		      sum += options->mu_rates[count];
+		    }
+		  sum /= options->muloci;
+		  for (i = 0; i < options->muloci; i++)
+		    {
+		      options->mu_rates[i] /= sum;
+		    }
+		}
+	      break;
+	    case 'C':
+	    default:
+	      options->gamma = FALSE;
+	      options->murates = FALSE;
+	      break;
+	    }
 	  break;
 	case '5':
 	  printf ("Which FST calculation method?\n");
