@@ -17,6 +17,7 @@ $Id: migrate_mpi.c,v 1.11 2001/09/07 23:56:13 beerli Exp $
 #include "world.h"
 #include "joint-chains.h"
 #include "data.h"
+#include "laguerre.h"
 /*should go into profile.h*/
 #define GRIDSIZE 9
 
@@ -27,8 +28,10 @@ extern void run_locus (world_fmt ** universe, int usize,
 
 long pack_databuffer (char **buffer, data_fmt * data, option_fmt * options);
 void unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options);
-void pack_allele_data(char **buffer, long *bufsize, data_fmt *data, long pop, long ind);
-void pack_sequence_data(char **buffer, long *bufsize, data_fmt *data, long pop, long ind);
+void pack_allele_data (char **buffer, long *bufsize, data_fmt * data,
+		       long pop, long ind);
+void pack_sequence_data (char **buffer, long *bufsize, data_fmt * data,
+			 long pop, long ind);
 void mpi_gradient_master (nr_fmt * nr, world_fmt * world, int *who);
 void mpi_results_master (double sendtype, world_fmt * world,
 			 long maxrep,
@@ -42,8 +45,8 @@ void mpi_results_worker (long bufs, world_fmt * world,
 				       long locus, long maxrep, long numpop));
 void assignloci_worker (world_fmt * world);
 void swap_atl (long from, long to, world_fmt * world);
-long pack_quantile(char **buffer, quantile_fmt quant, long n);
-void unpack_quantile(char *buffer, quantile_fmt quant, long n);
+long pack_quantile (char **buffer, quantile_fmt quant, long n);
+void unpack_quantile (char *buffer, quantile_fmt quant, long n);
 
 void
 mpi_runloci_master (long loci, int *who)
@@ -66,8 +69,7 @@ mpi_runloci_master (long loci, int *who)
       who[locusdone] = sender;
       if (numsent < loci)
 	{
-	  MPI_Send (&numsent, 1, MPI_LONG, sender, numsent + 1,
-		    comm_world);
+	  MPI_Send (&numsent, 1, MPI_LONG, sender, numsent + 1, comm_world);
 	  numsent++;
 	}
       else
@@ -75,10 +77,10 @@ mpi_runloci_master (long loci, int *who)
 	  MPI_Send (&loci, 1, MPI_LONG, sender, 0, comm_world);	//stop worker do wait for new loci
 	}
     }
-    for(sender=MIN (loci, numcpu - 1)+1; sender < numcpu; sender++)
-	{
-		MPI_Send (&loci, 1, MPI_LONG, sender, 0, comm_world);	//stop worker do wait for new loci
-	}
+  for (sender = MIN (loci, numcpu - 1) + 1; sender < numcpu; sender++)
+    {
+      MPI_Send (&loci, 1, MPI_LONG, sender, 0, comm_world);	//stop worker do wait for new loci
+    }
 }
 
 
@@ -133,12 +135,11 @@ mpi_likelihood_master (double *param, double *lparam,
   memcpy (temp + 1, param, (numelem - 1) * sizeof (double));
   memcpy (temp + numelem, lparam, (numelem - 1) * sizeof (double));
   memset (nr->locilikes, 0, sizeof (double) * world->loci);
-  for (worker = 1; worker < MIN(world->loci+1,numcpu); worker++)
+  for (worker = 1; worker < MIN (world->loci + 1, numcpu); worker++)
     {
-      MPI_Send (temp, (int) numelem2, MPI_DOUBLE, worker,
-		worker, comm_world);
+      MPI_Send (temp, (int) numelem2, MPI_DOUBLE, worker, worker, comm_world);
     }
-  for (worker = 1; worker < MIN(world->loci+1,numcpu); worker++)
+  for (worker = 1; worker < MIN (world->loci + 1, numcpu); worker++)
     {
       MPI_Recv (tmp, (int) world->loci, MPI_DOUBLE, MPI_ANY_SOURCE,
 		MPI_ANY_TAG, comm_world, &status);
@@ -168,20 +169,36 @@ mpi_likelihood_worker (world_fmt * world, helper_fmt * helper, long rep)
 {
   long locus, ww;
   nr_fmt *nr = helper->nr;
+  double *param = helper->expxv;
+  double *lparam = helper->xv; 
+  double *mu_rates = world->options->mu_rates;
   memset (nr->locilikes, 0, sizeof (double) * world->loci);
+  if (world->options->gamma)
+  {
+        if (lparam[nr->numpop2] > 9.903487553)
+	{  
+		lparam[nr->numpop2] = 9.903487553;
+	}
+	initgammacat (nr->categs, EXP (lparam[nr->numpop2]),1./* EXP (lparam[0])*/,
+		nr->rate, nr->probcat);
+  }  
+
   for (ww = 0; ww < locidone; ww++)
     {
       locus = nr->world->who[ww];
       if (!world->options->gamma)
 	{
-	  nr->locilikes[locus] = calc_locus_like (nr, nr->param, nr->lparam, locus);
+	  nr->locilikes[locus] =
+	    calc_locus_like (nr, param, lparam, locus) - mu_rates[locus];
 	}
       else
 	{
 	  helper->locus = locus;
 	  helper->nr->locilikes[locus] = gamma_locus_like (nr,
-							   helper->expxv,
-							   helper->xv, helper->weight, locus);
+							   param,
+							   lparam,
+							   helper->weight,
+							   locus);
 	}
     }
 }
@@ -294,15 +311,13 @@ mpi_gradient_master (nr_fmt * nr, world_fmt * world, int *who)
   memcpy (tempindex, nr->indeks, (numelem - 1) * sizeof (long));
   memcpy (temp + numelem, nr->lparam, (numelem - 1) * sizeof (double));
   temp[numelem2 - 1] = nr->profilenum;
-  for (locus = 1; locus < MIN(world->loci+1,numcpu); locus++)
+  for (locus = 1; locus < MIN (world->loci + 1, numcpu); locus++)
     {
-      MPI_Send (temp, (int) numelem2, MPI_DOUBLE, locus,
-		locus, comm_world);
-      MPI_Send (tempindex, (int) numelem, MPI_LONG, locus,
-		locus, comm_world);
+      MPI_Send (temp, (int) numelem2, MPI_DOUBLE, locus, locus, comm_world);
+      MPI_Send (tempindex, (int) numelem, MPI_LONG, locus, locus, comm_world);
     }
   memset (nr->d, 0, sizeof (double) * (numelem - 1));
-  for (locus = 1; locus <  MIN(world->loci+1,numcpu); locus++)
+  for (locus = 1; locus < MIN (world->loci + 1, numcpu); locus++)
     {
       copy_and_clear_d (nr);
       MPI_Recv (nr->d, (int) (numelem - 1), MPI_DOUBLE, MPI_ANY_SOURCE,
@@ -323,9 +338,16 @@ mpi_gradient_worker (helper_fmt * helper, nr_fmt * nr,
   for (ww = 0; ww < locidone; ww++)
     {
       locus = nr->world->who[ww];
-      copy_and_clear_d (nr);
-      simple_loci_derivatives (nr->d, nr, tyme, locus);
-      add_back_d (nr);
+      if(!nr->world->options->gamma)
+	 { 
+		copy_and_clear_d (nr);	  
+		simple_loci_derivatives (nr->d, nr, tyme, locus);
+		add_back_d (nr);
+	  }
+	  else
+	  {
+		gamma_locus_derivative (helper, locus);
+	  }
     }
 }
 
@@ -342,6 +364,8 @@ mpi_maximize_worker (world_fmt * world, long rep)
   long numelem2 = numelem * 2;
   double *temp;
   temp = (double *) calloc (numelem2, sizeof (double));
+  helper.xv = (double *) calloc (numelem2, sizeof (double));
+  helper.expxv = (double *) calloc (numelem2, sizeof (double));
   nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
   set_replicates (world, world->repkind, rep, &repstart, &repstop);
 
@@ -349,7 +373,7 @@ mpi_maximize_worker (world_fmt * world, long rep)
   MPI_Bcast (&Gmax, 1, MPI_LONG, MASTER, comm_world);
   create_nr (nr, world, Gmax, 0, world->loci, world->repkind, repstart);
   SETUPPARAM0 (world, nr, world->repkind,
-		    repstart, repstop, world->loci, MULTILOCUS, TRUE);
+	       repstart, repstop, world->loci, MULTILOCUS, TRUE);
   while (!done)
     {
       MPI_Recv (temp, (int) numelem2, MPI_DOUBLE, MASTER, MPI_ANY_TAG,
@@ -359,10 +383,10 @@ mpi_maximize_worker (world_fmt * world, long rep)
 	{
 	case MIGMPI_LIKE:
 	  memset (nr->locilikes, 0, sizeof (double) * world->loci);
-	  memcpy (nr->param, temp + 1, sizeof (double) * (numelem - 1));
-	  memcpy (nr->lparam, temp + numelem,
+	  memcpy (helper.expxv, temp + 1, sizeof (double) * (numelem - 1));
+	  memcpy (helper.xv, temp + numelem,
 		  sizeof (double) * (numelem - 1));
-	  fill_helper (&helper, nr->param, nr->lparam, world, nr);
+	  fill_helper (&helper, helper.expxv, helper.xv, world, nr);
 	  mpi_likelihood_worker (world, &helper, rep);
 	  MPI_Send (nr->locilikes, (int) world->loci, MPI_DOUBLE, MASTER,
 		    locus + 1, comm_world);
@@ -396,6 +420,8 @@ mpi_maximize_worker (world_fmt * world, long rep)
 	  exit (0);
 	}
     }
+	free(helper.xv);
+	free(helper.expxv);
   destroy_nr (nr, world);
 }
 
@@ -417,8 +443,8 @@ broadcast_options_worker (option_fmt * options)
 {
   long bufsize;
   char *buffer, *sbuffer;
-  MPI_Bcast (&bufsize,1, MPI_LONG, MASTER, comm_world);
-  buffer = (char *) calloc (bufsize+1, sizeof (char));    
+  MPI_Bcast (&bufsize, 1, MPI_LONG, MASTER, comm_world);
+  buffer = (char *) calloc (bufsize + 1, sizeof (char));
   sbuffer = buffer;
   MPI_Bcast (buffer, bufsize, MPI_CHAR, MASTER, comm_world);
   read_options_worker (&buffer, options);
@@ -446,7 +472,7 @@ broadcast_data_worker (data_fmt * data, option_fmt * options)
   MPI_Bcast (&bufsize, 1, MPI_LONG, MASTER, comm_world);
   buffer = (char *) calloc (bufsize, sizeof (char));
   MPI_Bcast (buffer, bufsize, MPI_CHAR, MASTER, comm_world);
-  unpack_databuffer(buffer, data, options);
+  unpack_databuffer (buffer, data, options);
   free (buffer);
 }
 
@@ -460,123 +486,132 @@ pack_databuffer (char **buffer, data_fmt * data, option_fmt * options)
 #endif
   char fp[LINESIZE];
   bufsize += LINESIZE;
-  *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-  sprintf (fp, "%c %li %li %li\n", options->datatype, (long) data->hasghost, data->numpop,
-	   data->loci);
-   bufsize += strlen (fp)+1;
-   *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);	   
-   strcat(*buffer, fp);
+  *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+  sprintf (fp, "%c %li %li %li\n", options->datatype, (long) data->hasghost,
+	   data->numpop, data->loci);
+  bufsize += strlen (fp) + 1;
+  *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+  strcat (*buffer, fp);
   for (locus = 0; locus < data->loci; locus++)
     {
       sprintf (fp, "%li\n", data->seq->sites[locus]);
-      bufsize += strlen (fp)+1;
-     *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-      strcat(*buffer, fp);
+      bufsize += strlen (fp) + 1;
+      *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+      strcat (*buffer, fp);
     }
   sprintf (fp, "%li %f\n", data->seq->addon, data->seq->fracchange);
-        bufsize += strlen (fp)+1;
-     *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-      strcat(*buffer, fp);
+  bufsize += strlen (fp) + 1;
+  *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+  strcat (*buffer, fp);
 // population data
   for (pop = 0; pop < data->numpop; pop++)
     {
-	sprintf (fp, "%li %s\n", data->numind[pop][FLOC], data->popnames[pop]);
-        bufsize += strlen (fp)+1;
-       *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-       strcat(*buffer, fp);
-	for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+      sprintf (fp, "%li %s\n", data->numind[pop][FLOC], data->popnames[pop]);
+      bufsize += strlen (fp) + 1;
+      *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+      strcat (*buffer, fp);
+      for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
 	{
-		sprintf (fp, "%*.*s\n", (int) options->nmlength, (int) options->nmlength,data->indnames[pop][ind]);
-		bufsize += strlen (fp)+1;
-		*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-		strcat(*buffer, fp);
-		if (strchr (SEQUENCETYPES, options->datatype))
-			pack_sequence_data(buffer, &bufsize, data, pop, ind);
-		else	
-			pack_allele_data(buffer,&bufsize, data, pop, ind);
+	  sprintf (fp, "%*.*s\n", (int) options->nmlength,
+		   (int) options->nmlength, data->indnames[pop][ind]);
+	  bufsize += strlen (fp) + 1;
+	  *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+	  strcat (*buffer, fp);
+	  if (strchr (SEQUENCETYPES, options->datatype))
+	    pack_sequence_data (buffer, &bufsize, data, pop, ind);
+	  else
+	    pack_allele_data (buffer, &bufsize, data, pop, ind);
 	}
     }
-// geofile	
+// geofile      
   if (options->geo)
-  {
-	for(pop=0; data->numpop * data->numpop ; pop++)
+    {
+      for (pop = 0; data->numpop * data->numpop; pop++)
 	{
-		sprintf (fp, "%f %f\n", data->geo[pop], data->lgeo[pop]);
-		bufsize += strlen (fp)+1;
-		*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-		strcat(*buffer, fp);
+	  sprintf (fp, "%f %f\n", data->geo[pop], data->lgeo[pop]);
+	  bufsize += strlen (fp) + 1;
+	  *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+	  strcat (*buffer, fp);
 	}
-  }
+    }
   // uepfile
-#ifdef UEP  
+#ifdef UEP
   if (options->uep)
-  {
-	sumtips =0;
-	for (pop = 0; pop < data->numpop; ++pop)
-		sumtips += data->numind[pop][FLOC];
-	sprintf (fp, "%li %li\n",sumtips, data->uepsites);
-	bufsize += strlen (fp)+1;
-	*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-	strcat(*buffer, fp);
-          if (strchr (SEQUENCETYPES, options->datatype))
+    {
+      sumtips = 0;
+      for (pop = 0; pop < data->numpop; ++pop)
+	sumtips += data->numind[pop][FLOC];
+      sprintf (fp, "%li %li\n", sumtips, data->uepsites);
+      bufsize += strlen (fp) + 1;
+      *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+      strcat (*buffer, fp);
+      if (strchr (SEQUENCETYPES, options->datatype))
 	{
-		for(pop=0; sumtips; pop++)
+	  for (pop = 0; sumtips; pop++)
+	    {
+	      for (i = 0; i < data->uepsites; i++)
 		{
-			for(i=0; i<data->uepsites; i++)
-			{
-				sprintf (fp, "%li\n",data->uep[pop][i]);
-				bufsize += strlen (fp)+1;
-				*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-				strcat(*buffer, fp);
-			}
+		  sprintf (fp, "%li\n", data->uep[pop][i]);
+		  bufsize += strlen (fp) + 1;
+		  *buffer =
+		    (char *) realloc (*buffer, sizeof (char) * bufsize);
+		  strcat (*buffer, fp);
 		}
+	    }
 	}
-	else
+      else
 	{
-		for(pop=0; sumtips; pop++)
+	  for (pop = 0; sumtips; pop++)
+	    {
+	      for (i = 0; i < data->uepsites; i++)
 		{
-			for(i=0; i<data->uepsites; i++)
-			{
-				sprintf (fp, "%li %li\n",data->uep[pop][i], data->uep[pop+sumtips][i]);
-				bufsize += strlen (fp)+1;
-				*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-				strcat(*buffer, fp);
-			}
+		  sprintf (fp, "%li %li\n", data->uep[pop][i],
+			   data->uep[pop + sumtips][i]);
+		  bufsize += strlen (fp) + 1;
+		  *buffer =
+		    (char *) realloc (*buffer, sizeof (char) * bufsize);
+		  strcat (*buffer, fp);
 		}
-	}		
-  }
+	    }
+	}
+    }
 
 #endif
   return bufsize;
 }
 
-void pack_allele_data(char **buffer, long *bufsize, data_fmt *data, long pop, long ind)
+void
+pack_allele_data (char **buffer, long *bufsize, data_fmt * data, long pop,
+		  long ind)
 {
-	char fp[LINESIZE];
-	long locus;
-	for (locus = 0; locus < data->loci; locus++)
-	{
-		sprintf (fp, "%s %s\n",data->yy[pop][ind][locus][0],data->yy[pop][ind][locus][1]);
-		*bufsize += strlen (fp)+1;
-		*buffer = (char *) realloc(*buffer, sizeof(char) * *bufsize);
-		strcat(*buffer, fp);
-	}
+  char fp[LINESIZE];
+  long locus;
+  for (locus = 0; locus < data->loci; locus++)
+    {
+      sprintf (fp, "%s %s\n", data->yy[pop][ind][locus][0],
+	       data->yy[pop][ind][locus][1]);
+      *bufsize += strlen (fp) + 1;
+      *buffer = (char *) realloc (*buffer, sizeof (char) * *bufsize);
+      strcat (*buffer, fp);
+    }
 }
 
-void pack_sequence_data(char **buffer, long *bufsize, data_fmt *data, long pop, long ind)
+void
+pack_sequence_data (char **buffer, long *bufsize, data_fmt * data, long pop,
+		    long ind)
 {
-	char *fp;
-	long locus;
-	fp = calloc(1,sizeof(char));
-	for (locus = 0; locus < data->loci; locus++)
-	{
-		fp = (char *) realloc(fp, data->seq->sites[locus] * sizeof(char));
-		sprintf (fp, "%s\n", data->yy[pop][ind][locus][0]);
-		*bufsize += strlen (fp)+1;
-		*buffer = (char *) realloc(*buffer, sizeof(char) * *bufsize);
-		strcat(*buffer, fp);
-	}
-	free(fp);
+  char *fp;
+  long locus;
+  fp = calloc (1, sizeof (char));
+  for (locus = 0; locus < data->loci; locus++)
+    {
+      fp = (char *) realloc (fp, data->seq->sites[locus] * sizeof (char));
+      sprintf (fp, "%s\n", data->yy[pop][ind][locus][0]);
+      *bufsize += strlen (fp) + 1;
+      *buffer = (char *) realloc (*buffer, sizeof (char) * *bufsize);
+      strcat (*buffer, fp);
+    }
+  free (fp);
 }
 
 // this function and get_data() do not mix well!
@@ -590,99 +625,109 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
   char *buf = buffer;
   char *input;
   long hasghost;
-  input = (char *) calloc(LINESIZE,sizeof(char));
-  sgets(input, LINESIZE, &buf);
+  input = (char *) calloc (LINESIZE, sizeof (char));
+  sgets (input, LINESIZE, &buf);
   sscanf (input, "%c%li%li%li", &options->datatype, &hasghost, &data->numpop,
-	   &data->loci);
+	  &data->loci);
   data->hasghost = (boolean) hasghost;
   init_data_structure1 (&data, options);
   for (locus = 0; locus < data->loci; locus++)
     {
-        sgets(input, LINESIZE, &buf);
-	sscanf (input,  "%li", &data->seq->sites[locus]);
+      sgets (input, LINESIZE, &buf);
+      sscanf (input, "%li", &data->seq->sites[locus]);
     }
-    sgets(input, LINESIZE, &buf);
-     sscanf (input, "%li%lf", &data->seq->addon, &data->seq->fracchange);
+  sgets (input, LINESIZE, &buf);
+  sscanf (input, "%li%lf", &data->seq->addon, &data->seq->fracchange);
 // population data
   for (pop = 0; pop < data->numpop; pop++)
     {
-	sgets(input, LINESIZE, &buf);
-	sscanf (input,  "%li%s", &data->numind[pop][FLOC], data->popnames[pop]);
-	init_data_structure2 (&data, options, pop);
-	for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+      sgets (input, LINESIZE, &buf);
+      sscanf (input, "%li%s", &data->numind[pop][FLOC], data->popnames[pop]);
+      init_data_structure2 (&data, options, pop);
+      for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
 	{
-		sgets(input, LINESIZE, &buf);
-		sscanf (input, "%s", data->indnames[pop][ind]);
-		if (strchr (SEQUENCETYPES, options->datatype))
+	  sgets (input, LINESIZE, &buf);
+	  sscanf (input, "%s", data->indnames[pop][ind]);
+	  if (strchr (SEQUENCETYPES, options->datatype))
+	    {
+	      for (locus = 0; locus < data->loci; locus++)
 		{
-			for (locus = 0; locus < data->loci; locus++)
-			{
-				input = (char *) realloc(input,sizeof(char) *(100+ data->seq->sites[locus]));
-				sgets(input, 100+ data->seq->sites[locus], &buf);
-				sscanf (input, "%s", data->yy[pop][ind][locus][0]);
-			}
+		  input =
+		    (char *) realloc (input,
+				      sizeof (char) * (100 +
+						       data->seq->
+						       sites[locus]));
+		  sgets (input, 100 + data->seq->sites[locus], &buf);
+		  sscanf (input, "%s", data->yy[pop][ind][locus][0]);
 		}
-		else	
+	    }
+	  else
+	    {
+	      for (locus = 0; locus < data->loci; locus++)
 		{
-			for (locus = 0; locus < data->loci; locus++)
-			{
-				sgets(input, LINESIZE, &buf);
-				sscanf (input,  "%s %s", data->yy[pop][ind][locus][0], data->yy[pop][ind][locus][1]);
-			}
+		  sgets (input, LINESIZE, &buf);
+		  sscanf (input, "%s %s", data->yy[pop][ind][locus][0],
+			  data->yy[pop][ind][locus][1]);
 		}
+	    }
 	}
     }
 // geofile
-  data->geo = (double *) calloc (1, sizeof (double) * data->numpop * data->numpop);
-  data->lgeo = (double *) calloc (1, sizeof (double) * data->numpop * data->numpop);
+  data->geo =
+    (double *) calloc (1, sizeof (double) * data->numpop * data->numpop);
+  data->lgeo =
+    (double *) calloc (1, sizeof (double) * data->numpop * data->numpop);
   if (!options->geo)
     {
       for (i = 0; i < data->numpop * data->numpop; i++)
 	data->geo[i] = 1.0;
     }
-    else  
+  else
     {
-	for(pop=0; data->numpop * data->numpop ; pop++)
+      for (pop = 0; data->numpop * data->numpop; pop++)
 	{
-		sgets(input, LINESIZE, &buf);
-		sscanf (input,  "%lf%lf", &data->geo[pop], &data->lgeo[pop]);
+	  sgets (input, LINESIZE, &buf);
+	  sscanf (input, "%lf%lf", &data->geo[pop], &data->lgeo[pop]);
 	}
-  }
+    }
   // uepfile
-#ifdef UEP  
+#ifdef UEP
   if (options->uep)
-  {
-	sgets(input, LINESIZE, &buf);
-	sscanf (input,  "%li%li",&sumtips, &data->uepsites);
-	data->uep = (long **) calloc (number_genomes (options->datatype) * sumtips,
-				sizeof (long *));
-	if (strchr (SEQUENCETYPES, options->datatype))
-	{		
-		for(pop=0; sumtips; pop++)
+    {
+      sgets (input, LINESIZE, &buf);
+      sscanf (input, "%li%li", &sumtips, &data->uepsites);
+      data->uep =
+	(long **) calloc (number_genomes (options->datatype) * sumtips,
+			  sizeof (long *));
+      if (strchr (SEQUENCETYPES, options->datatype))
+	{
+	  for (pop = 0; sumtips; pop++)
+	    {
+	      data->uep[i] = (long *) calloc (data->uepsites, sizeof (long));
+	      for (i = 0; i < data->uepsites; i++)
 		{
-			data->uep[i] = (long *) calloc (data->uepsites, sizeof (long));
-			for(i=0; i<data->uepsites; i++)
-			{
-				sgets(input, LINESIZE, &buf);
-				sscanf (input,  "%li",&data->uep[pop][i]);
-			}
+		  sgets (input, LINESIZE, &buf);
+		  sscanf (input, "%li", &data->uep[pop][i]);
 		}
+	    }
 	}
-	else
-	{		
-		for(pop=0; sumtips; pop++)
+      else
+	{
+	  for (pop = 0; sumtips; pop++)
+	    {
+	      data->uep[i] = (long *) calloc (data->uepsites, sizeof (long));
+	      data->uep[i + sumtips] =
+		(long *) calloc (data->uepsites, sizeof (long));
+	      for (i = 0; i < data->uepsites; i++)
 		{
-			data->uep[i] = (long *) calloc (data->uepsites, sizeof (long));
-			data->uep[i+sumtips] = (long *) calloc (data->uepsites, sizeof (long));
-			for(i=0; i<data->uepsites; i++)
-			{
-				sgets(input, LINESIZE, &buf);
-				sscanf (input,  "%li%li",&data->uep[pop][i], &data->uep[pop+sumtips][i]);
-			}
+		  sgets (input, LINESIZE, &buf);
+		  sscanf (input, "%li%li", &data->uep[pop][i],
+			  &data->uep[pop + sumtips][i]);
 		}
+	    }
 	}
-		
-  }
+
+    }
 #endif
   init_data_structure3 (data);
   /* replace this, if loci can have different number of ind */
@@ -699,7 +744,7 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
 	data->maxalleles[pop] = options->micro_stepnum;
       break;
     }
-	free(input);
+  free (input);
 }
 
 void
@@ -742,20 +787,20 @@ pack_result_buffer (char **buffer, world_fmt * world,
   char input[LINESIZE];
   timearchive_fmt **atl = world->atl;
   double ***apg0 = world->apg0;
-   long bufsize = 1;//maxrep * (1 + 4*numpop*numpop + world->options->lsteps) * 42 ;
-   (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+  long bufsize = 1;		//maxrep * (1 + 4*numpop*numpop + world->options->lsteps) * 42 ;
+  (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
   memset (*buffer, 0, sizeof (char) * bufsize);
   for (rep = 0; rep < maxrep; rep++)
     {
       sprintf (input, "%20.20f\n", atl[rep][locus].param_like);
-	bufsize += strlen(input) + 1;
-	(*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+      bufsize += strlen (input) + 1;
+      (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
       strcat (*buffer, input);
       for (pop = 0; pop < 4 * numpop * numpop; pop++)
 	{
 	  sprintf (input, "%20.20f\n", atl[rep][locus].parameters[pop]);
-	bufsize += strlen(input) + 1;
-	(*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+	  bufsize += strlen (input) + 1;
+	  (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
 	  strcat (*buffer, input);
 	}
     }
@@ -765,8 +810,8 @@ pack_result_buffer (char **buffer, world_fmt * world,
       for (pop = 0; pop < world->options->lsteps; pop++)
 	{
 	  sprintf (input, "%20.20f\n", apg0[rep][locus][pop]);
-	bufsize += strlen(input) + 1;
-   (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+	  bufsize += strlen (input) + 1;
+	  (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
 	  strcat (*buffer, input);
 	}
     }
@@ -815,8 +860,8 @@ pack_mighist_buffer (char **buffer, world_fmt * world,
   long j, i;
   mighistloci_fmt *aa;
   char input[LINESIZE];
-  long bufsize=1;
-    aa = &world->mighistloci[locus];
+  long bufsize = 1;
+  aa = &world->mighistloci[locus];
   strcpy (input, "");
   for (j = 0; j < aa->mighistnum; j++)
     bufsize += 100 + aa->mighist[j].migeventsize * 100;
@@ -862,9 +907,9 @@ unpack_sumfile_buffer (char *buffer, world_fmt * world,
 	{
 	  sgets (input, LINESIZE, &buf);
 	  sscanf (input, "%li ", &ta[r][l].tl[i].copies);
-	  ta[r][l].tl[i].lcopies = ln_copies(ta[r][l].tl[i].copies);
-	  for (j = 0; j < 3*numpop + numpop * (numpop-1); j++)
-	  {
+	  ta[r][l].tl[i].lcopies = ln_copies (ta[r][l].tl[i].copies);
+	  for (j = 0; j < 3 * numpop + numpop * (numpop - 1); j++)
+	    {
 	      sgets (input, LINESIZE, &buf);
 	      sscanf (input, "%lf", &ta[r][l].tl[i].data[j]);
 	    }
@@ -872,8 +917,7 @@ unpack_sumfile_buffer (char *buffer, world_fmt * world,
       for (i = 0; i < world->numpop2; i++)
 	{
 	  sgets (input, LINESIZE, &buf);
-	  sscanf (input, "%lg %lg", &ta[r][l].param[i],
-		  &ta[r][l].param0[i]);
+	  sscanf (input, "%lg %lg", &ta[r][l].param[i], &ta[r][l].param0[i]);
 	}
       log_param0 (ta[r][l].param0, ta[r][l].lparam0, world->numpop2);
       sgets (input, LINESIZE, &buf);
@@ -897,23 +941,22 @@ pack_sumfile_buffer (char **buffer, world_fmt * world,
   memset (*buffer, 0, sizeof (char) * bufsize);
   for (r = 0; r < maxrep; r++)
     {
-      sprintf (input, "%20li %20li %20li %20.20f \n", ta[r][l].T, ta[r][l].numpop,
-	       ta[r][l].sumtips, ta[r][l].param_like);
-	bufsize += strlen(input) + 1;
-   (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+      sprintf (input, "%20li %20li %20li %20.20f \n", ta[r][l].T,
+	       ta[r][l].numpop, ta[r][l].sumtips, ta[r][l].param_like);
+      bufsize += strlen (input) + 1;
+      (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
       strcat ((*buffer), input);
       for (i = 0; i < ta[r][l].T; i++)
 	{
 	  sprintf (input, "%20li\n", ta[r][l].tl[i].copies);
-	bufsize += strlen(input) + 1;
-   (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+	  bufsize += strlen (input) + 1;
+	  (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
 	  strcat ((*buffer), input);
-	  for (j = 0; j < 3*numpop + numpop * (numpop-1); j++)
+	  for (j = 0; j < 3 * numpop + numpop * (numpop - 1); j++)
 	    {
-	      sprintf (input, "%20.20f\n",
-		       ta[r][l].tl[i].data[j]);
-	bufsize += strlen(input) + 1;
-   (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+	      sprintf (input, "%20.20f\n", ta[r][l].tl[i].data[j]);
+	      bufsize += strlen (input) + 1;
+	      (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
 	      strcat ((*buffer), input);
 	    }
 	}
@@ -921,13 +964,13 @@ pack_sumfile_buffer (char **buffer, world_fmt * world,
 	{
 	  sprintf (input, "%20.20e %20.20e\n", ta[r][l].param[i],
 		   ta[r][l].param0[i]);
-	bufsize += strlen(input) + 1;
-   (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+	  bufsize += strlen (input) + 1;
+	  (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
 	  strcat ((*buffer), input);
 	}
       sprintf (input, "%20li %20.20e\n", ta[r][l].trials, ta[r][l].normd);
-	bufsize += strlen(input) + 1;
-   (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
+      bufsize += strlen (input) + 1;
+      (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
       strcat ((*buffer), input);
     }
   return bufsize;
@@ -952,7 +995,7 @@ mpi_results_master (double sendtype, world_fmt * world, long maxreplicate,
   buffer = (char *) calloc (bufsize, sizeof (char));
   temp[0] = sendtype;
   temp[1] = bufsize;
-  for (locus = 1; locus <  MIN(world->loci+1,numcpu); locus++)
+  for (locus = 1; locus < MIN (world->loci + 1, numcpu); locus++)
     {
       MPI_Send (temp, numelem2, MPI_DOUBLE, locus, locus, comm_world);
     }
@@ -969,8 +1012,7 @@ mpi_results_master (double sendtype, world_fmt * world, long maxreplicate,
       memset (buffer, 0, sizeof (char) * (bufsize + 1));
       sender = status.MPI_SOURCE;
       tag = status.MPI_TAG;
-      MPI_Recv (buffer, bufsize, MPI_CHAR,
-		sender, tag, comm_world, &status);
+      MPI_Recv (buffer, bufsize, MPI_CHAR, sender, tag, comm_world, &status);
       sbuffer = buffer;
       (*unpack) (buffer, world, tag - 1, maxreplicate, numpop);
     }
@@ -995,10 +1037,9 @@ mpi_results_worker (long bufs, world_fmt * world, long maxrep,
       buf = &buffer;
       locus = world->who[ww];
       bufsize = (*pack) (&buffer, world, locus, maxrep, numpop);
-	fflush (stdout);
+      fflush (stdout);
       MPI_Send (&bufsize, 1, MPI_LONG, MASTER, locus + 1, comm_world);
-      MPI_Send (buffer, bufsize, MPI_CHAR, MASTER, locus + 1,
-		comm_world);
+      MPI_Send (buffer, bufsize, MPI_CHAR, MASTER, locus + 1, comm_world);
     }
   free (*buf);
 }
@@ -1006,43 +1047,50 @@ mpi_results_worker (long bufs, world_fmt * world, long maxrep,
 // slownet profiler
 // 
 #ifdef SLOWNET
-void mpi_broadcast_results(world_fmt *world)
+void
+mpi_broadcast_results (world_fmt * world)
 {
-   long locus;
-   long bufsize;
-   char **buffer = &world->buffer;
-   long maxreplicate = (world->options->replicate
+  long locus;
+  long bufsize;
+  char **buffer = &world->buffer;
+  long maxreplicate = (world->options->replicate
 		       && world->options->replicatenum >
 		       0) ? world->options->replicatenum : 1;
-  MPI_Barrier(comm_world);
-	for(locus=0; locus < world->loci+1; locus++)
-  {
- 	if(myID==MASTER)
-		bufsize = pack_result_buffer(buffer,world, locus, maxreplicate, world->numpop);
-	MPI_Bcast (&bufsize, 1, MPI_LONG, MASTER, comm_world);
-	*buffer = (char *) realloc(*buffer, sizeof(char)*bufsize+1);
-        MPI_Bcast (*buffer, bufsize, MPI_CHAR, MASTER, comm_world);
-	if(myID!=MASTER)
-		unpack_result_buffer(*buffer, world, locus, maxreplicate, world->numpop);
-	memset(*buffer,0,sizeof(char)*bufsize);	 
-  }
-  MPI_Barrier(comm_world);
+  MPI_Barrier (comm_world);
+  for (locus = 0; locus < world->loci + 1; locus++)
+    {
+      if (myID == MASTER)
+	bufsize =
+	  pack_result_buffer (buffer, world, locus, maxreplicate,
+			      world->numpop);
+      MPI_Bcast (&bufsize, 1, MPI_LONG, MASTER, comm_world);
+      *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize + 1);
+      MPI_Bcast (*buffer, bufsize, MPI_CHAR, MASTER, comm_world);
+      if (myID != MASTER)
+	unpack_result_buffer (*buffer, world, locus, maxreplicate,
+			      world->numpop);
+      memset (*buffer, 0, sizeof (char) * bufsize);
+    }
+  MPI_Barrier (comm_world);
 
-  for(locus=0; locus < world->loci; locus++)
-  {
-	if(myID==MASTER)
-		bufsize = pack_sumfile_buffer(buffer,world, locus, maxreplicate, world->numpop);
-	MPI_Bcast (&bufsize, 1, MPI_LONG, MASTER, comm_world);
-	*buffer = (char *) realloc(*buffer, sizeof(char)*(bufsize+1));
-        MPI_Bcast (*buffer, bufsize, MPI_CHAR, MASTER, comm_world);
-	if(myID!=MASTER)
-		unpack_sumfile_buffer(*buffer, world, locus, maxreplicate, world->numpop); 
-	memset(*buffer,0,sizeof(char)*bufsize);
-   }
+  for (locus = 0; locus < world->loci; locus++)
+    {
+      if (myID == MASTER)
+	bufsize =
+	  pack_sumfile_buffer (buffer, world, locus, maxreplicate,
+			       world->numpop);
+      MPI_Bcast (&bufsize, 1, MPI_LONG, MASTER, comm_world);
+      *buffer = (char *) realloc (*buffer, sizeof (char) * (bufsize + 1));
+      MPI_Bcast (*buffer, bufsize, MPI_CHAR, MASTER, comm_world);
+      if (myID != MASTER)
+	unpack_sumfile_buffer (*buffer, world, locus, maxreplicate,
+			       world->numpop);
+      memset (*buffer, 0, sizeof (char) * bufsize);
+    }
 }
 
 void
-mpi_profiles_master (world_fmt *world, long nparam, int *profilewho)
+mpi_profiles_master (world_fmt * world, long nparam, int *profilewho)
 {
   long pnum;
   int sender;
@@ -1061,24 +1109,26 @@ mpi_profiles_master (world_fmt *world, long nparam, int *profilewho)
       numsent++;
     }
   for (pnum = 0; pnum < nparam; pnum++)
-    {   
-	   MPI_Recv (temp, 3, MPI_LONG, MPI_ANY_SOURCE, MPI_ANY_TAG,
+    {
+      MPI_Recv (temp, 3, MPI_LONG, MPI_ANY_SOURCE, MPI_ANY_TAG,
 		comm_world, &status);
-	pdone = temp[0];
-	bufsize =temp[1];
-	quantsize = temp[2];
+      pdone = temp[0];
+      bufsize = temp[1];
+      quantsize = temp[2];
       sender = status.MPI_SOURCE;
       profilewho[pdone] = sender;
-	*buffer = (char*) realloc(*buffer, sizeof(char)*(bufsize+quantsize+1));
-       memset(*buffer,0,sizeof(char)*(bufsize+quantsize+1));
-      MPI_Recv (*buffer, bufsize+quantsize, MPI_CHAR, sender, MPI_ANY_TAG, comm_world, &status);
-      unpack_quantile((*buffer)+bufsize, world->quantiles[pdone], GRIDSIZE);
-	memset((*buffer)+bufsize,0,sizeof(char)*quantsize);	 
-      fprintf(outfile,"%s\n\n",*buffer);
+      *buffer =
+	(char *) realloc (*buffer, sizeof (char) * (bufsize + quantsize + 1));
+      memset (*buffer, 0, sizeof (char) * (bufsize + quantsize + 1));
+      MPI_Recv (*buffer, bufsize + quantsize, MPI_CHAR, sender, MPI_ANY_TAG,
+		comm_world, &status);
+      unpack_quantile ((*buffer) + bufsize, world->quantiles[pdone],
+		       GRIDSIZE);
+      memset ((*buffer) + bufsize, 0, sizeof (char) * quantsize);
+      fprintf (outfile, "%s\n\n", *buffer);
       if (numsent < nparam)
 	{
-	  MPI_Send (&numsent, 1, MPI_LONG, sender, numsent + 1,
-		    comm_world);
+	  MPI_Send (&numsent, 1, MPI_LONG, sender, numsent + 1, comm_world);
 	  numsent++;
 	}
       else
@@ -1089,7 +1139,7 @@ mpi_profiles_master (world_fmt *world, long nparam, int *profilewho)
 }
 
 void
-mpi_profiles_worker (world_fmt *world, long *gmaxptr)
+mpi_profiles_worker (world_fmt * world, long *gmaxptr)
 {
   boolean done = FALSE;
   long pnum;
@@ -1097,21 +1147,24 @@ mpi_profiles_worker (world_fmt *world, long *gmaxptr)
   char *quantilebuffer;
   MPI_Status status;
   long qbufsize = 1;
-  quantilebuffer = (char *) calloc(qbufsize, sizeof(char));
+  quantilebuffer = (char *) calloc (qbufsize, sizeof (char));
   while (!done)
     {
-      MPI_Recv (&pnum, 1, MPI_LONG, MASTER, MPI_ANY_TAG,
-		comm_world, &status);
+      MPI_Recv (&pnum, 1, MPI_LONG, MASTER, MPI_ANY_TAG, comm_world, &status);
       if (status.MPI_TAG != 0)	//stop condition
 	{
 	  print_profile_likelihood_driver (pnum, world, gmaxptr);
 	  temp[0] = pnum;
-	  temp[1] = strlen(world->buffer);
-	   temp[2] = pack_quantile(&quantilebuffer, world->quantiles[pnum], GRIDSIZE);
-	  world->buffer = (char*) realloc(world->buffer, sizeof(char) * (temp[1] + temp[2] + 1));
-	  strcat(world->buffer,quantilebuffer);
+	  temp[1] = strlen (world->buffer);
+	  temp[2] =
+	    pack_quantile (&quantilebuffer, world->quantiles[pnum], GRIDSIZE);
+	  world->buffer =
+	    (char *) realloc (world->buffer,
+			      sizeof (char) * (temp[1] + temp[2] + 1));
+	  strcat (world->buffer, quantilebuffer);
 	  MPI_Send (temp, 3, MPI_LONG, MASTER, pnum + 1, comm_world);
-	  MPI_Send (world->buffer, temp[1]+temp[2], MPI_CHAR, MASTER, pnum + 1, comm_world);
+	  MPI_Send (world->buffer, temp[1] + temp[2], MPI_CHAR, MASTER,
+		    pnum + 1, comm_world);
 	  world->profilewho[profiledone++] = pnum;
 	}
       else
@@ -1119,40 +1172,42 @@ mpi_profiles_worker (world_fmt *world, long *gmaxptr)
 	  done = TRUE;
 	}
     }
-	free(quantilebuffer);
+  free (quantilebuffer);
 }
 
-long pack_quantile(char **buffer, quantile_fmt quant, long n)
+long
+pack_quantile (char **buffer, quantile_fmt quant, long n)
 {
-	long i;
-	char fp[LINESIZE];
-	long bufsize=LINESIZE;
-	*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-	sprintf(*buffer,"QUANTILEBUFFER:\n %s\n",quant.name);
-	for(i=0; i<n; i++)
-	{
-		sprintf(fp,"%20.20f\n",quant.param[i]);
-		bufsize += strlen(fp) +1;
-		*buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
-		strcat(*buffer,fp);
-	}
-	return bufsize;
+  long i;
+  char fp[LINESIZE];
+  long bufsize = LINESIZE;
+  *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+  sprintf (*buffer, "QUANTILEBUFFER:\n %s\n", quant.name);
+  for (i = 0; i < n; i++)
+    {
+      sprintf (fp, "%20.20f\n", quant.param[i]);
+      bufsize += strlen (fp) + 1;
+      *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+      strcat (*buffer, fp);
+    }
+  return bufsize;
 }
 
-void unpack_quantile(char *buffer, quantile_fmt quant, long n)
+void
+unpack_quantile (char *buffer, quantile_fmt quant, long n)
 {
-	long i;
-	char input[LINESIZE];
-	char *buf = buffer;
-	strcpy (input, "");
-	 sgets (input, LINESIZE, &buf);
-	 sgets (input, LINESIZE, &buf);
-	strcpy(quant.name,input);
-	for(i=0; i<n; i++)
-	{
-	     sgets (input, LINESIZE, &buf);
-	     quant.param[i] = atof(input);
-	}
+  long i;
+  char input[LINESIZE];
+  char *buf = buffer;
+  strcpy (input, "");
+  sgets (input, LINESIZE, &buf);
+  sgets (input, LINESIZE, &buf);
+  strcpy (quant.name, input);
+  for (i = 0; i < n; i++)
+    {
+      sgets (input, LINESIZE, &buf);
+      quant.param[i] = atof (input);
+    }
 }
 
 #endif
@@ -1223,21 +1278,23 @@ swap_atl (long from, long to, world_fmt * world)
 
 
 #ifdef SLOWNET
-void setup_parameter0_slowmpi(world_fmt * world, nr_fmt * nr, long repkind, long repstart,
-		  long repstop, long loci, long kind, boolean multilocus)
+void
+setup_parameter0_slowmpi (world_fmt * world, nr_fmt * nr, long repkind,
+			  long repstart, long repstop, long loci, long kind,
+			  boolean multilocus)
 {
   long locus, r;
   if (myID != MASTER)
     {
       if (multilocus)
 	{
-	for (locus = 0; locus < loci; locus++)
+	  for (locus = 0; locus < loci; locus++)
 	    {
-		 if (repkind == SINGLECHAIN)
+	      if (repkind == SINGLECHAIN)
 		{
 		  for (r = repstart; r < repstop; r++)
 		    create_apg0 (nr->apg0[r][locus], nr,
-				 &world->atl[r][locus]);
+				 &world->atl[r][locus], locus);
 		}
 	      else
 		{
@@ -1245,7 +1302,7 @@ void setup_parameter0_slowmpi(world_fmt * world, nr_fmt * nr, long repkind, long
 		    {
 		      for (r = repstart; r < repstop; r++)
 			create_apg0 (nr->apg0[r][locus], nr,
-				     &world->atl[r][locus]);
+				     &world->atl[r][locus], locus);
 		      interpolate_like (nr, locus);
 		    }
 		  else
@@ -1262,7 +1319,7 @@ void setup_parameter0_slowmpi(world_fmt * world, nr_fmt * nr, long repkind, long
 	    {
 	      for (r = repstart; r < repstop; r++)
 		create_apg0 (nr->apg0[r][world->locus], nr,
-			     &world->atl[r][world->locus]);
+			     &world->atl[r][world->locus], world->locus);
 	    }
 	  else
 	    {
@@ -1270,7 +1327,7 @@ void setup_parameter0_slowmpi(world_fmt * world, nr_fmt * nr, long repkind, long
 		{
 		  for (r = repstart; r < repstop; r++)
 		    create_apg0 (nr->apg0[r][world->locus], nr,
-				 &world->atl[r][world->locus]);
+				 &world->atl[r][world->locus], world->locus);
 		  interpolate_like (nr, world->locus);
 		}
 	      for (r = repstart; r < repstop; r++)
@@ -1282,8 +1339,10 @@ void setup_parameter0_slowmpi(world_fmt * world, nr_fmt * nr, long repkind, long
 }
 #endif
 
-void setup_parameter0_mpi(world_fmt * world, nr_fmt * nr, long repkind, long repstart,
-		  long repstop, long loci, long kind, boolean multilocus)
+void
+setup_parameter0_mpi (world_fmt * world, nr_fmt * nr, long repkind,
+		      long repstart, long repstop, long loci, long kind,
+		      boolean multilocus)
 {
   long locus, r;
   long ll;
@@ -1298,7 +1357,7 @@ void setup_parameter0_mpi(world_fmt * world, nr_fmt * nr, long repkind, long rep
 		{
 		  for (r = repstart; r < repstop; r++)
 		    create_apg0 (nr->apg0[r][locus], nr,
-				 &world->atl[r][locus]);
+				 &world->atl[r][locus], locus);
 		}
 	      else
 		{
@@ -1306,7 +1365,7 @@ void setup_parameter0_mpi(world_fmt * world, nr_fmt * nr, long repkind, long rep
 		    {
 		      for (r = repstart; r < repstop; r++)
 			create_apg0 (nr->apg0[r][locus], nr,
-				     &world->atl[r][locus]);
+				     &world->atl[r][locus], locus);
 		      interpolate_like (nr, locus);
 		    }
 		  else
@@ -1323,7 +1382,7 @@ void setup_parameter0_mpi(world_fmt * world, nr_fmt * nr, long repkind, long rep
 	    {
 	      for (r = repstart; r < repstop; r++)
 		create_apg0 (nr->apg0[r][world->locus], nr,
-			     &world->atl[r][world->locus]);
+			     &world->atl[r][world->locus], world->locus);
 	    }
 	  else
 	    {
@@ -1331,7 +1390,7 @@ void setup_parameter0_mpi(world_fmt * world, nr_fmt * nr, long repkind, long rep
 		{
 		  for (r = repstart; r < repstop; r++)
 		    create_apg0 (nr->apg0[r][world->locus], nr,
-				 &world->atl[r][world->locus]);
+				 &world->atl[r][world->locus], world->locus);
 		  interpolate_like (nr, world->locus);
 		}
 	      for (r = repstart; r < repstop; r++)
