@@ -47,8 +47,8 @@ extern double mpi_likelihood_master (double *param, double *lparam,
 extern void broadcast_options_master (option_fmt * options);
 extern void broadcast_options_worker (option_fmt * options);
 
-extern void broadcast_data_master(data_fmt *data, option_fmt *options);
-extern void broadcast_data_worker(data_fmt *data, option_fmt *options);
+extern void broadcast_data_master (data_fmt * data, option_fmt * options);
+extern void broadcast_data_worker (data_fmt * data, option_fmt * options);
 extern void mpi_results_master (double sendtype, world_fmt * world,
 				long maxrep,
 				void (*unpack) (char *buffer,
@@ -83,14 +83,16 @@ extern void mpi_gmax_worker (world_fmt * world);
 extern void mpi_send_stop (world_fmt * world);
 extern void mpi_results_stop (void);
 extern void assignloci_worker (world_fmt * world);
-void setup_parameter0_mpi(world_fmt * world, nr_fmt * nr, long repkind, long repstart,
-		  long repstop, long loci, long kind, boolean multilocus);
+void setup_parameter0_mpi (world_fmt * world, nr_fmt * nr, long repkind,
+			   long repstart, long repstop, long loci, long kind,
+			   boolean multilocus);
 #ifdef SLOWNET
-void mpi_broadcast_results(world_fmt *world);
-void mpi_profiles_master (world_fmt *world, long nparam, int *profilewho);
-void mpi_profiles_worker (world_fmt *world, long *gmaxptr);
-void setup_parameter0_slowmpi(world_fmt * world, nr_fmt * nr, long repkind, long repstart,
-		  long repstop, long loci, long kind, boolean multilocus);
-#endif /*slownet*/
-#endif /*mpi*/
+void mpi_broadcast_results (world_fmt * world);
+void mpi_profiles_master (world_fmt * world, long nparam, int *profilewho);
+void mpi_profiles_worker (world_fmt * world, long *gmaxptr);
+void setup_parameter0_slowmpi (world_fmt * world, nr_fmt * nr, long repkind,
+			       long repstart, long repstop, long loci,
+			       long kind, boolean multilocus);
+#endif /*slownet */
+#endif /*mpi */
 #endif
