@@ -25,7 +25,7 @@
 
 typedef char allele_type[DEFAULT_ALLELENMLENGTH];
 
-typedef double pair[2]; 
+typedef double pair[2];
 typedef double sitelike[4];
 typedef sitelike *ratelike;
 typedef ratelike *phenotype;
@@ -71,7 +71,7 @@ xarray_fmt;
 typedef union ueparray_fmt
 {
   double *a;
-  pair * s;
+  pair *s;
 }
 ueparray_fmt;
 #endif
@@ -261,7 +261,10 @@ typedef struct _option
   short thetaguess;
   short migrguess;
   boolean gamma;
+  boolean murates;
   double alphavalue;
+  double *mu_rates;
+  long muloci;
   long burn_in;
   short heating;
   double *thetag;
@@ -359,13 +362,13 @@ typedef struct tarchive_fmt
 {
   long copies;
   double lcopies;
-  double *data; //hold content
-  double *point;  // points into data
-  double *wait; // points into data
-  double *kt;  //points to wait
-  double *km; //points to wait
-  double *p;   // points to point
-  double *mindex; // points to point
+  double *data;			//hold content
+  double *point;		// points into data
+  double *wait;			// points into data
+  double *kt;			//points to wait
+  double *km;			//points to wait
+  double *p;			// points to point
+  double *mindex;		// points to point
 }
 tarchive_fmt;
 
@@ -379,11 +382,11 @@ typedef struct timearchive_fmt
   double thb;
   double alpha;
   tarchive_fmt *tl;
-  double *parameters;// holds data
-  double *param; // pointer into parameters
-  double *param0; //pointer into parameters
-  double *lparam0; //pointer into parameters
-  double *likelihood; //pointer into parameters
+  double *parameters;		// holds data
+  double *param;		// pointer into parameters
+  double *param0;		//pointer into parameters
+  double *lparam0;		//pointer into parameters
+  double *likelihood;		//pointer into parameters
   long trials;
   double normd;
 }
@@ -437,6 +440,10 @@ typedef struct _worldoption
 {
   boolean gamma;
   double alphavalue;
+  boolean murates;
+  long muloci;
+  double *mu_rates;
+  double *lmu_rates;
   short migration_model;
   char *custm;
   char *custm2;
@@ -555,7 +562,7 @@ typedef struct _world
   int *profilewho;
 #endif
 #endif
-  char *buffer;	 // buffer for profiles, not needed before profiletables()
+  char *buffer;			// buffer for profiles, not needed before profiletables()
   long loci;
   long skipped;			/*loci with no data */
   long locus;			/* the current locus, if single then set to 0 */
@@ -594,8 +601,8 @@ typedef struct _world
   double **migproblist;
   long *design0list;
 
-	/*nr related */
-	  double ***apg0;		/* part-loglikelihoods of param0 */
+  /*nr related */
+  double ***apg0;		/* part-loglikelihoods of param0 */
   double ***apg;		/* part-loglikelihoods of param */
 
   /*heating scheme */
@@ -724,6 +731,7 @@ typedef struct helper_fmt
   double *xv;
   double *expxv;
   double sign;
+  double lamda;
 }
 helper_fmt;
 
@@ -866,9 +874,10 @@ typedef long longer[3];		/* used in random.c */
 extern long *seed;
 extern long *newseed;
 #ifdef SLOWNET
-extern  double (*calc_like) (helper_fmt *, double *, double *);
+extern double (*calc_like) (helper_fmt *, double *, double *);
 extern void (*calc_gradient) (nr_fmt *, helper_fmt *, double *);
-extern  void (*setup_param0) (world_fmt * , nr_fmt * , long , long , long , long , long , boolean );
+extern void (*setup_param0) (world_fmt *, nr_fmt *, long, long, long, long,
+			     long, boolean);
 
 #endif
 
