@@ -45,7 +45,7 @@ extern void save_parmfile (option_fmt * options);
 extern void set_plot (option_fmt * options);
 extern void synchronize_param (world_fmt * world, option_fmt * options);
 extern void resynchronize_param (world_fmt * world);
-extern long save_options_buffer (char *buffer, option_fmt * options);
+extern long save_options_buffer (char **buffer, option_fmt * options);
 extern void read_options_master (option_fmt * options);
 extern void read_options_worker (char **buffer, option_fmt * options);
 #endif /*OPTIONS_INCLUDE */
