@@ -31,7 +31,7 @@ $Id: profile.c,v 1.55 2001/09/07 23:56:13 beerli Exp $
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
 #endif
-long find_profilelike (double testlike, long whichprob, double minparam,
+long find_profilelike (double testlike, double prob, long whichprob, double minparam,
 		       double maxparam, double *param, double *llike,
 		       long which, world_fmt * world, boolean QD, boolean QD2,
 		       double *mlparam, double *normd, nr_fmt * nr);
@@ -44,7 +44,7 @@ void print_profile_title (world_fmt * world);
 void print_profile_table (char method, long which, char *var, double likes[],
 			  double **param, world_fmt * world);
 void print_profile_percentile (world_fmt * world);
-void sprint_percentile_header (char * outfile, boolean first);
+void sprint_percentile_header (char *outfile, boolean first);
 void allocate_profile_percentiles (world_fmt * world);
 void destroy_profile_percentiles (world_fmt * world);
 void print_menu_profile (long which, long nn);
@@ -93,7 +93,7 @@ long set_profile_param (double *param, long which, long *allwhich,
 void addinvar (double *param, long *fixed, long *allwhich, double *xvals,
 	       long start, long len);
 void sprint_nice_param (double parameter, double bottom, double top,
-		       char * file);
+			char *file);
 
 
 
@@ -189,7 +189,7 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
   prepare_header (var, which, world);
   if (world->options->printprofile)
     {
-	print_profile_table (method, which, var, likes, param, world);
+      print_profile_table (method, which, var, likes, param, world);
     }
   if (world->options->printprofsummary)
     {
@@ -216,13 +216,13 @@ print_profile_table (char method, long which, char *var, double likes[],
   long elem =
     world->options->gamma ? world->numpop * world->numpop +
     1 : world->numpop * world->numpop;
-	
+
 //  FILE *outfile = world->outfile;
-  char fp[LINESIZE * 10]; //large local string buffer
-  char *buffer = world->buffer; // buffer for printing whole table
+  char fp[LINESIZE * 10];	//large local string buffer
+  char *buffer = world->buffer;	// buffer for printing whole table
   char *temp, *var2, temp2[LINESIZE], likestr[LINESIZE], *paramstr;
   double likemax = -DBL_MAX;
-  memset(buffer,0,sizeof(char)*strlen(buffer));
+  memset (buffer, 0, sizeof (char) * strlen (buffer));
   var2 =
     (char *) calloc (1,
 		     sizeof (char) * MAX (LINESIZE,
@@ -273,18 +273,18 @@ print_profile_table (char method, long which, char *var, double likes[],
       break;
     }
   sprintf (fp, "\n\nProfile likelihood for parameter %s\n", var);
-  strcat(buffer,fp);
+  strcat (buffer, fp);
   sprintf (fp, "%s\n", methodstring);
-  strcat(buffer,fp);
+  strcat (buffer, fp);
   sprint_line (fp, '-', 79, CONT);
-  strcat(buffer,fp);
+  strcat (buffer, fp);
   if (method == 'd')
     sprintf (fp, "      Ln(L)     %7.7s     %s\n", var, var2);
   else
     sprintf (fp, "Per.  Ln(L)     %7.7s     %s\n", var, var2);
-    strcat(buffer,fp);
+  strcat (buffer, fp);
   sprint_line (fp, '-', 79, START);
-    strcat(buffer,fp);
+  strcat (buffer, fp);
   for (i = 0; i < GRIDSIZE; i++)
     {
       if (likemax < MIN (likes[i], DBL_MAX))
@@ -327,7 +327,7 @@ print_profile_table (char method, long which, char *var, double likes[],
 	  else
 	    sprintf (fp, "%3.3f     -           -       %s\n",
 		     probabilities[i], paramstr);
-	  strcat(buffer,fp);
+	  strcat (buffer, fp);
 	}
       else
 	{
@@ -344,14 +344,14 @@ print_profile_table (char method, long which, char *var, double likes[],
 			 probabilities[i], likestr,
 			 param[i][which], paramstr);
 	    }
-	  strcat(buffer,fp);
+	  strcat (buffer, fp);
 	}
     }
   sprint_line (fp, '-', 79, STOP);
-    strcat(buffer,fp);
+  strcat (buffer, fp);
   sprintf (fp,
 	   "- = not possible to evaluate, most likely value either 0.0 or Infinity\n   in the parameter direction, the likelihood surface is so flat\n    that the calculation of the percentile(s)  failed.\n");
-	     strcat(buffer,fp);
+  strcat (buffer, fp);
   free (paramstr);
   free (var2);
 }
@@ -394,26 +394,26 @@ print_profile_percentile (world_fmt * world)
   boolean first = TRUE;
   boolean last = FALSE;
   char fp[LINESIZE];
-  memset(world->buffer,0,sizeof(char)*strlen(world->buffer));
+  memset (world->buffer, 0, sizeof (char) * strlen (world->buffer));
   sprintf (fp, "\n\n");
-  strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
   sprint_line (fp, '=', 79, CONT);
-  strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
   sprintf (fp,
 	   "Summary of profile likelihood percentiles of all parameters\n");
-  strcat(world->buffer,fp);	   
+  strcat (world->buffer, fp);
   sprint_line (fp, '=', 79, CONT);
-  strcat(world->buffer,fp);
-  sprintf(fp, "\n");
-  strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
+  sprintf (fp, "\n");
+  strcat (world->buffer, fp);
   sprint_percentile_header (fp, first);
-  strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
   for (i = 0; i < world->numpop2 + (long) world->options->gamma; i++)
     {
       if (world->quantiles[i].name[0] == '\0')
 	continue;		/* this variable was not estimated, so return */
       sprintf (fp, "%-10.10s  ", world->quantiles[i].name);
-      strcat(world->buffer,fp);
+      strcat (world->buffer, fp);
       for (jj = 0; jj < GRIDSIZE; jj++)
 	{
 	  j = warp (jj);
@@ -423,22 +423,22 @@ print_profile_percentile (world_fmt * world)
 	    sprintf (fp, "      -       ");
 	  else
 	    sprint_nice_param (world->quantiles[i].param[j], 0.000001,
-			      999.99999, fp);
-	    strcat(world->buffer,fp);
+			       999.99999, fp);
+	  strcat (world->buffer, fp);
 	}
       sprintf (fp, "\n");
-      strcat(world->buffer,fp);
+      strcat (world->buffer, fp);
     }
   sprintf (fp, "\n\n");
-  strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
   sprint_percentile_header (fp, last);
-  strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
   for (i = 0; i < world->numpop2 + (long) world->options->gamma; i++)
     {
       if (world->quantiles[i].name[0] == '\0')
 	continue;		/* this variable was not estimated, so return */
       sprintf (fp, "%-10.10s  ", world->quantiles[i].name);
-      strcat(world->buffer,fp);
+      strcat (world->buffer, fp);
       for (jj = 0; jj < GRIDSIZE; jj++)
 	{
 	  j = warp (jj);
@@ -448,24 +448,24 @@ print_profile_percentile (world_fmt * world)
 	    sprintf (fp, "      -       ");
 	  else
 	    sprint_nice_param (world->quantiles[i].param[j], 0.000001,
-			      999.99999, fp);
-	   strcat(world->buffer,fp);
+			       999.99999, fp);
+	  strcat (world->buffer, fp);
 	}
       sprintf (fp, "\n");
-      strcat(world->buffer,fp);
+      strcat (world->buffer, fp);
     }
 
   sprintf (fp, "\n");
-  strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
   sprint_line (fp, '-', 80, CONT);
-  strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
   sprintf (fp,
 	   "- = not possible to evaluate, most likely value either 0.0 or Infinity\n    in the parameter direction, the likelihood surface is so flat\n    that the percentiles cannot be calculated.\n");
-    strcat(world->buffer,fp);
+  strcat (world->buffer, fp);
 }
 
 void
-sprint_nice_param (double parameter, double bottom, double top, char * file)
+sprint_nice_param (double parameter, double bottom, double top, char *file)
 {
   if (parameter > 0.000001 && parameter < 999.99999)
     sprintf (file, " %11.6f  ", parameter);
@@ -474,24 +474,22 @@ sprint_nice_param (double parameter, double bottom, double top, char * file)
 }
 
 void
-sprint_percentile_header (char * outfile, boolean first)
+sprint_percentile_header (char *outfile, boolean first)
 {
   const double probabilities[] = GRID2;
   long i;
   char fp[LINESIZE];
   if (first)
-    sprintf (fp,
-	     "Parameter                          Lower percentiles\n");
+    sprintf (fp, "Parameter                          Lower percentiles\n");
   else
-    sprintf (fp,
-	     "Parameter                          Upper percentiles\n");
-  strcat(outfile,fp);		 
+    sprintf (fp, "Parameter                          Upper percentiles\n");
+  strcat (outfile, fp);
   sprintf (fp, "            ");
-  strcat(outfile,fp);
+  strcat (outfile, fp);
   sprint_line (fp, '-', 68, CONT);
-  strcat(outfile,fp);
+  strcat (outfile, fp);
   sprintf (fp, "            ");
-  strcat(outfile,fp);
+  strcat (outfile, fp);
   for (i = 0; i < GRIDSIZE - 1; i++)
     {
       if (first)
@@ -508,15 +506,15 @@ sprint_percentile_header (char * outfile, boolean first)
 	sprintf (fp, "    MLE       ");
       else
 	sprintf (fp, "    %5.3f     ", probabilities[i]);
-      strcat(outfile,fp);
+      strcat (outfile, fp);
     }
   if (probabilities[i] == 0.5)
     sprintf (fp, "    MLE\n");
   else
     sprintf (fp, "    %5.3f\n", probabilities[i]);
-  strcat(outfile,fp);
+  strcat (outfile, fp);
   sprint_line (fp, '-', 80, CONT);
-  strcat(outfile,fp);
+  strcat (outfile, fp);
 }
 
 
@@ -689,8 +687,8 @@ profile_max_percentiles (long which, double *likes, double **param,
       memcpy (param[i], mlparam,
 	      sizeof (double) * (world->numpop2 +
 				 (long) world->options->gamma));
-      trials =/* prob was testlike*/
-	find_profilelike (prob, i, minparam, maxparam, param[i],
+      trials =	
+	find_profilelike (testlike, prob, i, minparam, maxparam, param[i],
 			  &likes[i], which, world, QD, QD2, mlparam, &normd,
 			  nr);
       if (world->options->progress)
@@ -1163,23 +1161,13 @@ addinvar (double *param, long *fixed, long *allwhich, double *xvals,
 }
 
 long
-find_profilelike (double testlike, long whichprob, double minparam,
+find_profilelike (double testlike, double prob, long whichprob, double minparam,
 		  double maxparam, double *testparam, double *llike,
 		  long which, world_fmt * world, boolean QD, boolean QD2,
 		  double *mlparam, double *normd, nr_fmt * nr)
 {
   const double probabilities[] = GRID;
-#ifndef MPI
-  long locus, r;
-#else
-#ifdef SLOWNET
-//long locus, r;
-#endif
-#endif
-
-  //  boolean test;
   double tmp;
-  //  double likes=0;
   double xlow, low;
   double x, mid = -DBL_MAX;
   double xhigh, high;
@@ -1188,6 +1176,7 @@ find_profilelike (double testlike, long whichprob, double minparam,
   double *ltestparam;
   ltestparam = (double *) calloc (nr->numpop2 + 1, sizeof (double));
   *normd = -1;
+    prepare_broyden (PROFILE, world, &helper.multilocus);
   if (probabilities[whichprob] < 0.5)
     {
       xhigh = maxparam;
@@ -1210,53 +1199,22 @@ find_profilelike (double testlike, long whichprob, double minparam,
 	  xhigh = maxparam;
 	}
     }
+  // QD=TRUE -> calculate only CALCLIKE for parameter
+  // QD2=TRUE -> assumes QD and then adds a maximizer step
+  // if both are false maximize all parameters
   if (QD)
     {
-/*#ifndef MPI
-      for (locus = 0; locus < world->loci; locus++)
-	{
-	  if (world->repkind == SINGLECHAIN)
-	    {
-	      for (r = 0; r < world->repstop; r++)
-		{
-		  create_apg0 (nr->apg0[r][locus], nr, &world->atl[r][locus]);
-		}
-	    }
-	  else
-	    {
-	     //interpolate_like(nr, locus);
-	      for (r = nr->repstart; r < nr->repstop; r++)
-		create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
-	    }
-	}
-#else
-#ifdef SLOWNET
-      for (locus = 0; locus < world->loci; locus++)
-	{
-	  if (world->repkind == SINGLECHAIN)
-	    {
-	      for (r = 0; r < world->repstop; r++)
-		{
-		  create_apg0 (nr->apg0[r][locus], nr, &world->atl[r][locus]);
-		}
-	    }
-	  else
-	    {
-		exit(-1);
-	     // interpolate_like(nr, locus);
-	      //for (r = nr->repstart; r < nr->repstop; r++)
-		//create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
-	    }
-	}
-#endif
-#endif 
-*/
       memcpy (testparam, mlparam, sizeof (double) *
-	      (world->numpop2 + (long) world->options->gamma));
+	  	      (world->numpop2 + (long) world->options->gamma));
       nr->profilenum = set_profile_param (testparam, which, nr->profiles,
 					  xlow, nr->values, world);
       testparam[which] = xlow;
       set_logparam (ltestparam, testparam, nr->partsize);
+      //SETUPPARAM0 (world, nr, world->repkind, nr->repstart, nr->repstop,
+      //	world->loci, PROFILE, helper.multilocus);
+      if(world->options->gamma)
+	initgammacat (nr->categs, testparam[nr->numpop2],1./* EXP (lparam[0])*/,
+		      nr->rate, nr->probcat);
       fill_helper (&helper, testparam, ltestparam, nr->world, nr);
       low = CALCLIKE (&helper, testparam, ltestparam);
       memcpy (testparam, mlparam, sizeof (double) *
@@ -1265,8 +1223,12 @@ find_profilelike (double testlike, long whichprob, double minparam,
 					  xhigh, nr->values, world);
       testparam[which] = xhigh;
       set_logparam (ltestparam, testparam, nr->partsize);
+      if(world->options->gamma)
+	        initgammacat (nr->categs, testparam[nr->numpop2],1./* EXP (lparam[0])*/,
+		nr->rate, nr->probcat);
       fill_helper (&helper, testparam, ltestparam, world, nr);
       high = CALCLIKE (&helper, testparam, ltestparam);
+  //    testlike = high - 0.5 * find_chi (1, prob);
     }
   else
     {
@@ -1280,10 +1242,14 @@ find_profilelike (double testlike, long whichprob, double minparam,
 					  xhigh, nr->values, world);
       maximize (testparam, world, nr, PROFILE, world->repkind);
       high = nr->llike;
-	  	      testlike = high - 0.5 * find_chi (1, testlike);
-      
-	  if(high< world->atl[0][world->loci].param_like)
-		printf("%i> DARN: high=%f ml=%f xigh=%f mlparam[which]=%f testlike=%f\n", myID, high, world->atl[0][world->loci].param_like,xhigh,mlparam[which],testlike); 
+
+      //	testlike = high - 0.5 * find_chi (1, prob);
+
+      if (high < world->atl[0][world->loci].param_like)
+	printf
+	  ("%i> DARN: high=%f ml=%f xigh=%f mlparam[which]=%f testlike=%f\n",
+	   myID, high, world->atl[0][world->loci].param_like, xhigh,
+	   mlparam[which], testlike);
     }
   panic = 0;
   x = (xhigh + xlow) / 2.;
@@ -1296,6 +1262,9 @@ find_profilelike (double testlike, long whichprob, double minparam,
 					      nr->profiles, x,
 					      nr->values, world);
 	  testparam[which] = x;
+	        initgammacat (nr->categs, testparam[nr->numpop2],1./* EXP (lparam[0])*/,
+		nr->rate, nr->probcat);
+
 	  set_logparam (ltestparam, testparam, nr->partsize);
 	  fill_helper (&helper, testparam, ltestparam, world, nr);
 	  mid = CALCLIKE (&helper, testparam, ltestparam);
