@@ -926,8 +926,9 @@ sitesort2 (world_fmt * world, data_fmt * data, long sites, long locus)
 		|| ((seq->weight[jj - 1] == 0) && (seq->weight[jg - 1] == 0));
 	      tied = samewt
 		&& (seq->category[jj - 1] == seq->category[jg - 1]);
-	      flip = ((!samewt) && (seq->weight[jj - 1] == 0)) 
-		|| (samewt &&  (seq->category[jj - 1] >seq->category[jg -1]));
+	      flip = ((!samewt) && (seq->weight[jj - 1] == 0))
+		|| (samewt
+		    && (seq->category[jj - 1] > seq->category[jg - 1]));
 	      k = 0;
 	      pop = 0;
 	      kk = -1;
