@@ -26,7 +26,8 @@ void print_ancestor (FILE * out, world_fmt * world, long copies);
 void update_uepanc (world_fmt * world);
 void check_uep_root (node * p, world_fmt * world);
 
-void setup_uep (world_fmt * world, option_fmt * options)
+void
+setup_uep (world_fmt * world, option_fmt * options)
 {
   if (options->uep)
     {
@@ -44,9 +45,10 @@ void setup_uep (world_fmt * world, option_fmt * options)
     }
 }
 
-void pseudonu_twostate(proposal_fmt * proposal, 
-	ueparray_fmt *xx1, double *lx1, double v1, 
-	ueparray_fmt *xx2, double *lx2, double v2)
+void
+pseudonu_twostate (proposal_fmt * proposal,
+		   ueparray_fmt * xx1, double *lx1, double v1,
+		   ueparray_fmt * xx2, double *lx2, double v2)
 {
 //  static long count=0;
   long j;
@@ -59,31 +61,31 @@ void pseudonu_twostate(proposal_fmt * proposal,
   pair *x2;
   v1 = EXP (-v1 * rs);
   v2 = EXP (-v2 * rs);
-  r = r/rs;
-  s = s/rs;
-  for(j=0;j<proposal->world->data->uepsites;j++)
-  {
-	x1 = &(xx1->s[j]);
-	x2 = &(xx2->s[j]);
-	pija11 = (v1 * r + s) * (*x1)[0] + (s - v1 * s) * (*x1)[1];
-	pija12 = (v2 * r + s) * (*x2)[0] + (s - v2 * s) * (*x2)[1];
-	pija21 = (s - v1 * s) * (*x1)[0] + (v1 * s + r) *(*x1)[1];
-	pija22 = (s - v2 * s) * (*x2)[0] + (v2 * s + r) * (*x2)[1];
-	(*x1)[0] = pija11 * pija12;
-	(*x1)[1] = pija21 * pija22;
-  }
+  r = r / rs;
+  s = s / rs;
+  for (j = 0; j < proposal->world->data->uepsites; j++)
+    {
+      x1 = &(xx1->s[j]);
+      x2 = &(xx2->s[j]);
+      pija11 = (v1 * r + s) * (*x1)[0] + (s - v1 * s) * (*x1)[1];
+      pija12 = (v2 * r + s) * (*x2)[0] + (s - v2 * s) * (*x2)[1];
+      pija21 = (s - v1 * s) * (*x1)[0] + (v1 * s + r) * (*x1)[1];
+      pija22 = (s - v2 * s) * (*x2)[0] + (v2 * s + r) * (*x2)[1];
+      (*x1)[0] = pija11 * pija12;
+      (*x1)[1] = pija21 * pija22;
+    }
   //*lx1 += lx2;
   //count++;
   //if (count == SCALEINTERVAL)
-   // {
-     // count = 0;
-      //if ((*xx1)[0] > x3m)
-//	x3m = (*xx1)[0];
+  // {
+  // count = 0;
+  //if ((*xx1)[0] > x3m)
+//      x3m = (*xx1)[0];
 //      if ((*xx1)[1] > x3m)
-//	x3m = (*xx1)[1];
+//      x3m = (*xx1)[1];
 //      (*xx1)[0] /= x3m;
- //     (*xx1)[1] /= x3m;
-//	*lx1 += log (x3m); 
+  //     (*xx1)[1] /= x3m;
+//      *lx1 += log (x3m); 
 //    }
 }
 
@@ -105,30 +107,30 @@ twostate_nuview (node * mother, world_fmt * world, const long locus)
   children (mother, &d1, &d2);
   v1 = EXP (-d1->v * rs);
   v2 = EXP (-d2->v * rs);
-  r = r/rs;
-  s = s/rs;
-for(j=0;j<world->data->uepsites; j++)
-{
-	xx1 = &d1->ux.s[j];
-	xx2 = &d2->ux.s[j];
-	xx3 = &mother->ux.s[j];
+  r = r / rs;
+  s = s / rs;
+  for (j = 0; j < world->data->uepsites; j++)
+    {
+      xx1 = &d1->ux.s[j];
+      xx2 = &d2->ux.s[j];
+      xx3 = &mother->ux.s[j];
 
-	pija11 = (v1 * r + s) * (*xx1)[0] + (s - v1 * s) * (*xx1)[1];
-	pija12 = (v2 * r + s) * (*xx2)[0] + (s - v2 * s) * (*xx2)[1];
-	(*xx3)[0] = pija11 * pija12;
-	pija21 = (s - v1 * s) * (*xx1)[0] + (v1 * s + r) * (*xx1)[1];
-	pija22 = (s - v2 * s) * (*xx2)[0] + (v2 * s + r) * (*xx2)[1];
-	(*xx3)[0] = pija21 * pija22;
-}
+      pija11 = (v1 * r + s) * (*xx1)[0] + (s - v1 * s) * (*xx1)[1];
+      pija12 = (v2 * r + s) * (*xx2)[0] + (s - v2 * s) * (*xx2)[1];
+      (*xx3)[0] = pija11 * pija12;
+      pija21 = (s - v1 * s) * (*xx1)[0] + (v1 * s + r) * (*xx1)[1];
+      pija22 = (s - v2 * s) * (*xx2)[0] + (v2 * s + r) * (*xx2)[1];
+      (*xx3)[0] = pija21 * pija22;
+    }
 //  count++;
 //  mother->scale[0] = d1->scale[0] + d2->scale[0];
 //  if (count == SCALEINTERVAL)
 //    {
 //      count = 0;
 //      if (xx3[0] > x3m)
-//	x3m = xx3[0];
+//      x3m = xx3[0];
 //      if (xx3[1] > x3m)
-//	x3m = xx3[1];
+//      x3m = xx3[1];
 //      xx3[0] /= x3m;
 //      xx3[1] /= x3m;
 //      mother->scale[0] += log (x3m); 
@@ -258,27 +260,28 @@ constrain_distance_uep (long **uep, long uepsites, double **distm, long tips)
     }
 }
 
-void set_uepvalues(data_fmt *data, node **treenode, long tii, long ii)
+void
+set_uepvalues (data_fmt * data, node ** treenode, long tii, long ii)
 {
-	long j;
-	for(j=0;j<data->uepsites;j++)
-		{
-			switch(data->uep[ii][j])
-			{
-				case '0':
-					treenode[tii]->ux.s[j][0] = 1.;
-					treenode[tii]->ux.s[j][1] = 0.; 	
-					break;
-				case '1':
-					treenode[tii]->ux.s[j][0] = 0.;
-					treenode[tii]->ux.s[j][1] = 1.; 	
-					break;
-				case '?':
-				default:
-					treenode[tii]->ux.s[j][0] = treenode[tii]->ux.s[j][1]=1.; 	
-					break;
-			}
-		}
+  long j;
+  for (j = 0; j < data->uepsites; j++)
+    {
+      switch (data->uep[ii][j])
+	{
+	case '0':
+	  treenode[tii]->ux.s[j][0] = 1.;
+	  treenode[tii]->ux.s[j][1] = 0.;
+	  break;
+	case '1':
+	  treenode[tii]->ux.s[j][0] = 0.;
+	  treenode[tii]->ux.s[j][1] = 1.;
+	  break;
+	case '?':
+	default:
+	  treenode[tii]->ux.s[j][0] = treenode[tii]->ux.s[j][1] = 1.;
+	  break;
+	}
+    }
 }
 
 void
@@ -292,7 +295,7 @@ make_uep_values (world_fmt * world, data_fmt * data, long locus)
     {
       for (ii = 0; ii < world->sumtips; ii++)
 	{
-		set_uepvalues(data, treenode, ii, ii);
+	  set_uepvalues (data, treenode, ii, ii);
 	}
     }
   else
@@ -302,9 +305,10 @@ make_uep_values (world_fmt * world, data_fmt * data, long locus)
 	  poptips = data->numind[pop][0] / 2;
 	  for (ind = 0; ind < poptips; ind++)
 	    {
-		set_uepvalues(data, treenode, tmp+ind, ii);
-		set_uepvalues(data, treenode, tmp+ind+poptips, halfuep+ii);
-	        ii++;
+	      set_uepvalues (data, treenode, tmp + ind, ii);
+	      set_uepvalues (data, treenode, tmp + ind + poptips,
+			     halfuep + ii);
+	      ii++;
 	    }
 	  tmp += poptips;
 	}
@@ -320,21 +324,21 @@ pseudo_tl_uep (ueparray_fmt * xx1, ueparray_fmt * xx2, double v1, double v2,
   double tterm;
   pair *x1;
   summ = 0.0;
-      for (i = 0; i < world->data->uepsites; i++)
-	{
-	  x1 = &(xx1->s[i]);
-	  tterm =
-	    world->data->uepfreq0 * (*x1)[0] + world->data->uepfreq1 * (*x1)[1];
-	  summ +=  (log (tterm) + proposal->mf[i]);
-	}
-      return summ;
+  for (i = 0; i < world->data->uepsites; i++)
+    {
+      x1 = &(xx1->s[i]);
+      tterm =
+	world->data->uepfreq0 * (*x1)[0] + world->data->uepfreq1 * (*x1)[1];
+      summ += (log (tterm) + proposal->mf[i]);
+    }
+  return summ;
 }
 
 
 double
 treelike_uep (world_fmt * world, long locus)
 {
-	double tterm;
+  double tterm;
   double summ;
   long i;
 //  double scale;
@@ -342,14 +346,14 @@ treelike_uep (world_fmt * world, long locus)
   pair *x1;
   p = crawlback (world->root->next);
   summ = 0.0;
-      for (i = 0; i < world->data->uepsites; i++)
-	{
-	  x1 = &(p->ux.s[i]);
-//	  scale = p->uepscale[i];
-	  tterm =
-		world->data->uepfreq0 * (*x1)[0] + world->data->uepfreq1 * (*x1)[1];
-	  summ += (log (tterm) );//+ scale);
-	}
+  for (i = 0; i < world->data->uepsites; i++)
+    {
+      x1 = &(p->ux.s[i]);
+//        scale = p->uepscale[i];
+      tterm =
+	world->data->uepfreq0 * (*x1)[0] + world->data->uepfreq1 * (*x1)[1];
+      summ += (log (tterm));	//+ scale);
+    }
   return summ;
 }				/* treelikelihood */
 
@@ -370,7 +374,7 @@ update_uep (node * p, world_fmt * world)
       if (p->type != 'r')
 	{
 	  for (i = 0; i < world->data->uepsites; ++i)
-		  p->uep[i] = MAX(p->ux.s[i][0], p->ux.s[i][1]);
+	    p->uep[i] = MAX (p->ux.s[i][0], p->ux.s[i][1]);
 	}
     }
 }
@@ -1251,7 +1255,9 @@ pseudo_ueplikelihood (world_fmt * world, proposal_fmt * proposal)
   tb = uep_check (root, showtop (crawlback (proposal->target))->uep,
 		  uepsites);
   first = first_uep2 (root, root, uepsites);
-  firstb = showtop (crawlback (first = first_uep (first, proposal->world->root, uepsites)));
+  firstb =
+    showtop (crawlback
+	     (first = first_uep (first, proposal->world->root, uepsites)));
   proposal->firstuep = first;
   if (proposal->world->options->ueprate > 0.0)
     proposal->treelen =
