@@ -42,10 +42,12 @@ extern void analyze_uep (world_fmt * world);
 extern void alloc_uepanc (long ***uepanc, long size, long numpop, long loci);
 extern void update_uepanc (world_fmt * world);
 extern void setup_uep (world_fmt * world, option_fmt * options);
-extern void pseudonu_twostate(proposal_fmt * proposal, ueparray_fmt *xx1, double *lx1,
-	      double v1, ueparray_fmt *xx2, double *lx2, double v2);
-extern double pseudo_tl_uep (ueparray_fmt * xx1, ueparray_fmt * xx2, double v1, double v2,
-	       proposal_fmt * proposal, world_fmt * world);
+extern void pseudonu_twostate (proposal_fmt * proposal, ueparray_fmt * xx1,
+			       double *lx1, double v1, ueparray_fmt * xx2,
+			       double *lx2, double v2);
+extern double pseudo_tl_uep (ueparray_fmt * xx1, ueparray_fmt * xx2,
+			     double v1, double v2, proposal_fmt * proposal,
+			     world_fmt * world);
 
 #endif
 
