@@ -83,7 +83,7 @@ void plot_surface_header2 (FILE * outfile, long locus, char plotvar[]);
 void plot_surface2 (FILE * outfile, long x, long locus, long numpop,
 		    char ****plane, plotmax_fmt ** plotmax,
 		    char **popnames, char plotvar[], long migrmodel);
-void print_alpha_curve (world_fmt * world, timearchive_fmt ** atl);
+void print_alpha_curve (world_fmt * world, timearchive_fmt ** atl, long *gmaxptr);
 void create_loci_plot (world_fmt * world, char ***plane,
 		       nr_fmt * nr, long loci);
 void create_locus_plot (world_fmt * world, char ***plane,
@@ -167,9 +167,29 @@ create_world (world_fmt ** world, char *name, long loci)
 void
 fill_worldoptions (worldoption_fmt * wopt, option_fmt * options, long numpop)
 {
+  long i;
   long numpop2 = numpop * numpop;
   wopt->gamma = options->gamma;
   wopt->alphavalue = options->alphavalue;
+  wopt->murates = options->murates;
+  wopt->mu_rates = (double *) calloc (options->muloci, sizeof (double));
+  wopt->lmu_rates = (double *) calloc (options->muloci, sizeof (double));
+  if (wopt->murates)
+    {
+      memcpy (wopt->mu_rates, options->mu_rates,
+	      sizeof (double) * options->muloci);
+      for (i = 0; i < options->muloci; i++)
+	{
+	  wopt->lmu_rates[i] = log (options->mu_rates[i]);
+	}
+    }
+  else
+    {
+      for (i = 0; i < options->muloci; i++)
+	{
+	  wopt->mu_rates[i] = 1.;
+	}
+    }
   wopt->migration_model = options->migration_model;
   wopt->custm = (char *) calloc (numpop2 + 2, sizeof (char));
   strcpy (wopt->custm, options->custm);
@@ -303,15 +323,17 @@ init_world (world_fmt * world, data_fmt * data, option_fmt * options)
   long locus, i, rep;
   long custmlen = 0;
   world->options = (worldoption_fmt *) calloc (1, sizeof (worldoption_fmt));
-  world->buffer = (char *) calloc(LINESIZE,sizeof(char));
+  world->buffer = (char *) calloc (LINESIZE, sizeof (char));
 #ifdef MPI
   world->who = (int *) calloc (data->loci, sizeof (int));
 #ifdef SLOWNET
-  world->profilewho = (int *) calloc (data->numpop*data->numpop+2, sizeof (int));
+  world->profilewho =
+    (int *) calloc (data->numpop * data->numpop + 2, sizeof (int));
 #endif
 #endif
   world->data = (worlddata_fmt *) calloc (1, sizeof (worlddata_fmt));
   world->data->seq = (seqmodel_fmt *) calloc (1, sizeof (seqmodel_fmt));
+  options->muloci = data->loci;
   fill_worldoptions (world->options, options, data->numpop);
   fill_worlddata (world->data, world, data, data->numpop, options->readsum);
   if (!options->readsum)
@@ -423,9 +445,11 @@ init_world (world_fmt * world, data_fmt * data, option_fmt * options)
   //setup UEP
   setup_uep (world, options);
 #endif
- // nr related structures
-   alloc_apg (&world->apg0, world->repstop, world->loci, world->options->lsteps);
-  alloc_apg (&world->apg, world->repstop, world->loci, world->options->lsteps);
+  // nr related structures
+  alloc_apg (&world->apg0, world->repstop, world->loci,
+	     world->options->lsteps);
+  alloc_apg (&world->apg, world->repstop, world->loci,
+	     world->options->lsteps);
 
   /* tree and treetimes are not yet allocated */
 }
@@ -607,7 +631,7 @@ print_list (world_fmt * world, option_fmt * options, data_fmt * data)
       //printf ("%i> entering mpi_results_table\n", myID);
       maxreplicate = (options->replicate ?
 		      ((options->replicatenum > 0) ?
-		       options->replicatenum + 1 : options->lchains + 1) : 1);
+		       options->replicatenum  : options->lchains ) : 1);
       mpi_results_master (MIGMPI_RESULT, world, maxreplicate,
 			  unpack_result_buffer);
 #endif
@@ -622,9 +646,6 @@ print_list (world_fmt * world, option_fmt * options, data_fmt * data)
 	  plot_surface (world, options, data, world->plane,
 			world->options->plotintervals + 2);
 	}
-      if (world->options->gamma)
-	print_alpha_curve (world, world->atl);
-      /* print_cov(world, world->numpop, world->loci, world->cov); */
     }
 }
 
@@ -790,7 +811,7 @@ plot_surface2 (FILE * outfile, long x, long locus, long numpop,
 
 
 void
-print_alpha_curve (world_fmt * world, timearchive_fmt ** atl)
+print_alpha_curve (world_fmt * world, timearchive_fmt ** atl, long *gmaxptr)
 {
   const double alphas[19] = {
     0.001, 0.002, 0.005,
@@ -802,7 +823,7 @@ print_alpha_curve (world_fmt * world, timearchive_fmt ** atl)
   };
   long nnn;
   double adiff, amin = 0, amax;
-  long r, g, a, gmax = 1, loci = world->loci;
+  long g, a, loci = world->loci;
   double likes[21];
   char confidence[21];
   nr_fmt *nr;
@@ -812,44 +833,18 @@ print_alpha_curve (world_fmt * world, timearchive_fmt ** atl)
   long repstart, repstop;
   helper_fmt helper;
   double alpha = atl[0][loci].param[world->numpop2];
+  //
+  double normd= DBL_MAX;
+  long kind = PROFILE; 
+  long repkind = world->repkind;
+  long rep=0;
+  char save_a = world->options->custm2[world->numpop2];
+  world->options->custm2[world->numpop2] = 'c';
   helper.multilocus = TRUE;
   testparam = (double *) calloc (world->numpop2 + 1, sizeof (double));
   ltestparam = (double *) calloc (world->numpop2 + 1, sizeof (double));
   if (world->options->gamma && loci - world->skipped > 1)
     {
-      nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
-      for (g = 0; g < loci; g++)
-	{
-	  for (r = 0; r < world->repstop; r++)
-	    {
-	      if (gmax < atl[r][g].T)
-		gmax = atl[r][g].T;
-	    }
-	}
-      create_nr (nr, world, gmax, 0, loci, world->repkind, 0);
-      nnn = nr->partsize;
-      nr->skiploci = world->data->skiploci;
-      set_replicates (world, world->repkind, world->rep, &repstart, &repstop);
-      SETUPPARAM0 (world, nr, world->repkind, repstart, repstop,
-			world->loci, MULTILOCUS, helper.multilocus);
-      if (!world->options->replicate)
-	{
-	  r = 0;
-	  for (g = 0; g < world->loci; g++)
-	    create_apg0 (nr->apg0[r][g], nr, &world->atl[r][g]);
-	}
-      else
-	{
-	  for (r = 0; r < world->repstop; r++)
-	    {
-	      for (g = 0; g < world->loci; g++)
-		create_multiapg0 (nr->apg0[r][g], nr, r, g);
-	    }
-	}
-
-      memcpy (testparam, atl[0][loci].param, sizeof (double) *
-	      (world->numpop2 + 1));
-      set_logparam (ltestparam, testparam, world->numpop2 + 1);
       contours = (double **) calloc (1, sizeof (double *) * 1);
       contours[0] =
 	(double *) calloc (1, sizeof (double) * 1 * CONTOURLEVELS);
@@ -858,15 +853,33 @@ print_alpha_curve (world_fmt * world, timearchive_fmt ** atl)
 	{
 	  contours[0][g] += atl[0][loci].param_like;
 	}
-      if (world->options->progress)
-	fprintf (stdout, "           Printing Alpha x Ln(likelihood)\n");
-      if (world->options->writelog)
-	fprintf (world->options->logfile,
-		 "           Printing Alpha x Ln(likelihood)\n");
-      initgammacat (nr->categs, testparam[nr->numpop2], testparam[0],
-		    nr->rate, nr->probcat);
-      fill_helper (&helper, testparam, ltestparam, world, nr);
-      likes[19] = CALCLIKE (&helper, testparam, ltestparam);
+		if (world->options->progress)
+			fprintf (stdout, "           Printing Alpha x Ln(likelihood)\n");
+		if (world->options->writelog)
+			fprintf (world->options->logfile,
+			"           Printing Alpha x Ln(likelihood)\n");
+	
+      nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
+      create_nr (nr, world, *gmaxptr, world->numpop2, world->loci,
+	     world->repkind, world->rep);
+      nnn = nr->partsize;
+      nr->skiploci = world->data->skiploci;
+      set_replicates (world, world->repkind, world->rep, &repstart, &repstop);
+	  
+	nr->repstart = repstart;
+	nr->repstop = repstop;
+      memcpy (testparam, atl[0][loci].param, sizeof (double) *
+	      (world->numpop2 + 1));
+      set_logparam (ltestparam, testparam, world->numpop2 + 1);
+      SETUPPARAM0 (world, nr, world->repkind, repstart, repstop,
+		   world->loci, PROFILE, helper.multilocus);
+//	  initgammacat (nr->categs, testparam[nr->numpop2], testparam[0],
+//			nr->rate, nr->probcat);
+//	  fill_helper (&helper, testparam, ltestparam, world, nr);
+//	  likes[19] = CALCLIKE (&helper, testparam, ltestparam);
+	memcpy(world->param0,testparam, (world->numpop2+1)*sizeof(double));
+	do_profiles (world, nr, &likes[19], &normd, kind, rep, repkind);
+	likes[19] = nr->llike;
       if (alpha < alphas[0])
 	amin = 1e-10;
       for (a = 0; a < 19; a++)
@@ -886,11 +899,14 @@ print_alpha_curve (world_fmt * world, timearchive_fmt ** atl)
 	  memcpy (testparam, atl[0][loci].param, sizeof (double) *
 		  (world->numpop2 + 1));
 	  testparam[nr->numpop2] = alphas[a];
-	  set_logparam (ltestparam, testparam, world->numpop2 + 1);
-	  initgammacat (nr->categs, testparam[nr->numpop2], testparam[0],
-			nr->rate, nr->probcat);
-	  fill_helper (&helper, testparam, ltestparam, world, nr);
-	  likes[a] = CALCLIKE (&helper, testparam, ltestparam);
+//	  set_logparam (ltestparam, testparam, world->numpop2 + 1);
+//	  initgammacat (nr->categs, testparam[nr->numpop2], testparam[0],
+//			nr->rate, nr->probcat);
+//	  fill_helper (&helper, testparam, ltestparam, world, nr);
+//	  likes[a] = CALCLIKE (&helper, testparam, ltestparam);
+	memcpy(world->param0,testparam, (world->numpop2+1)*sizeof(double));
+	do_profiles (world, nr, &likes[a], &normd, kind, rep, repkind);
+	likes[a] = nr->llike;
 	}
       for (a = 0; a < 19; a++)
 	{
@@ -923,7 +939,7 @@ print_alpha_curve (world_fmt * world, timearchive_fmt ** atl)
 	    }
 	}
       fprintf (outfile, "Ln-Likelihood curve for the shape\n");
-      fprintf (outfile, "parameter Alpha    [1/square(CV(mu))]\n");
+      fprintf (outfile, "parameter Alpha    [1/(CV(mu)^2)]\n");
       fprintf (outfile, "-------------------------------------\n\n");
       fprintf (outfile, "Legend:\n");
       fprintf (outfile, "   X = Maximum likelihood\n");
@@ -964,6 +980,7 @@ print_alpha_curve (world_fmt * world, timearchive_fmt ** atl)
 		 alphas[a], likes[a], confidence[a]);
       destroy_nr (nr, world);
     }
+  world->options->custm2[world->numpop2] = save_a;	
   free (testparam);
   free (ltestparam);
 }
@@ -1095,15 +1112,15 @@ void
 apocalypse_now (world_fmt * world)
 {
   long j, i, z;
-  if(world->options->plot)
-  {
-  for (i = 0; i < world->loci + 1; i++)
+  if (world->options->plot)
     {
-      for (j = 0; j < world->numpop; j++)
-	free (world->plane[i][j]);
-      free (world->plane[i]);
+      for (i = 0; i < world->loci + 1; i++)
+	{
+	  for (j = 0; j < world->numpop; j++)
+	    free (world->plane[i][j]);
+	  free (world->plane[i]);
+	}
     }
-  }	
   free (world->plane);
   for (j = 0; j < world->repstop; j++)
     {
@@ -1125,14 +1142,14 @@ apocalypse_now (world_fmt * world)
   free (world->atl);
   if (strchr (SEQUENCETYPES, world->options->datatype))
     {
-	if(world->tbl != NULL)
+      if (world->tbl != NULL)
 	{
-		for (i = 0; i < world->options->rcategs; i++)
-		{
-		for (j = 0; j < world->options->categs; j++)
-			free (world->tbl[i][j]);
-		free (world->tbl[i]);
-		}
+	  for (i = 0; i < world->options->rcategs; i++)
+	    {
+	      for (j = 0; j < world->options->categs; j++)
+		free (world->tbl[i][j]);
+	      free (world->tbl[i]);
+	    }
 	}
     }
   free (world->data->skiploci);
@@ -1144,6 +1161,8 @@ apocalypse_now (world_fmt * world)
   free (world->options->sym2param);
   free (world->options->custm);
   free (world->options->custm2);
+  free (world->options->mu_rates);
+  free (world->options->lmu_rates);
   free (world->options);
   free (world->nodep);
   free (world->likelihood);
@@ -1198,29 +1217,31 @@ print_menu_chain (char type, long chain, long steps,
 	{
 	  if (writelog)
 	    {
-	      fprintf (logg, "%s   Locus %li: Start conditions:\n", nowstr, world->locus+1);
+	      fprintf (logg, "%s   Locus %li: Start conditions:\n", nowstr,
+		       world->locus + 1);
 	      print_param (logg, world->options->usem, world->param0,
 			   world->numpop, spacer);
 	      fprintf (logg, "%sStart-tree-log(L)=%f\n", spacer,
 		       world->likelihood[0]);
 
 	    }
-	  fprintf (stdout, "%s   Locus %li: Start conditions:\n", nowstr, world->locus+1);
+	  fprintf (stdout, "%s   Locus %li: Start conditions:\n", nowstr,
+		   world->locus + 1);
 	  print_param (stdout, world->options->usem, world->param0,
 		       world->numpop, spacer);
 	  fprintf (stdout, "%sStart-tree-log(L)=%f\n", spacer,
 		   world->likelihood[0]);
-		   	  if (writelog)
+	  if (writelog)
 	    {
 	      if (world->repkind != SINGLECHAIN)
 		fprintf (logg, "%s   Multiple chain estimates:\n", nowstr);
 	      else
-		fprintf (logg, "%s   Locus: %li: %*s chain %3li:\n", nowstr, world->locus+1,
-			 type == 's' ? 5 : 4, type == 's' ? "Short" : "Long",
-			 chain + 1);
-			fprintf (logg,
-				"%sln L(Param)=ln (P(G|Param)/P(G|Param0))=%s,\n",
-				spacer, strllike);
+		fprintf (logg, "%s   Locus: %li: %*s chain %3li:\n", nowstr,
+			 world->locus + 1, type == 's' ? 5 : 4,
+			 type == 's' ? "Short" : "Long", chain + 1);
+	      fprintf (logg,
+		       "%sln L(Param)=ln (P(G|Param)/P(G|Param0))=%s,\n",
+		       spacer, strllike);
 	      if (world->repkind == SINGLECHAIN)
 		fprintf (logg,
 			 "%sStart-tree-ln(L)=ln P(D|G)=%f\n",
@@ -1228,19 +1249,20 @@ print_menu_chain (char type, long chain, long steps,
 	      print_param (logg, world->options->usem, world->param0,
 			   world->numpop, spacer);
 	    }
-		prognose_time (nowstr, world, options, steps, spacer);
+	  prognose_time (nowstr, world, options, steps, spacer);
 	}
       else
 	{
 	  if (world->repkind != SINGLECHAIN)
 	    fprintf (stdout, "%s   Multiple chain estimates:\n", nowstr);
 	  else
-	    fprintf (stdout, "%s   Locus %li: %*s chain %3li:\n", nowstr, world->locus+1,
-		     type == 's' ? 5 : 4, type == 's' ? "Short" : "Long",
-		     chain + 1);
-		prognose_time (nowstr, world, options, steps, spacer);
+	    fprintf (stdout, "%s   Locus %li: %*s chain %3li:\n", nowstr,
+		     world->locus + 1, type == 's' ? 5 : 4,
+		     type == 's' ? "Short" : "Long", chain + 1);
+	  prognose_time (nowstr, world, options, steps, spacer);
 
-	  fprintf (stdout, "%sln L(Param)=ln (P(G|Param)/P(G|Param0)):%15.15s\n",
+	  fprintf (stdout,
+		   "%sln L(Param)=ln (P(G|Param)/P(G|Param0)):%15.15s\n",
 		   spacer, strllike);
 	  if (world->repkind == SINGLECHAIN)
 	    fprintf (stdout,
@@ -1253,12 +1275,12 @@ print_menu_chain (char type, long chain, long steps,
 	      if (world->repkind != SINGLECHAIN)
 		fprintf (logg, "%s   Multiple chain estimates:\n", nowstr);
 	      else
-		fprintf (logg, "%s   Locus %li: %*s chain %3li:\n", nowstr, world->locus+1,
-			 type == 's' ? 5 : 4, type == 's' ? "Short" : "Long",
-			 chain + 1);
-			fprintf (logg,
-				"%sln L(Param)=ln (P(G|Param)/P(G|Param0))=%s,\n",
-				spacer, strllike);
+		fprintf (logg, "%s   Locus %li: %*s chain %3li:\n", nowstr,
+			 world->locus + 1, type == 's' ? 5 : 4,
+			 type == 's' ? "Short" : "Long", chain + 1);
+	      fprintf (logg,
+		       "%sln L(Param)=ln (P(G|Param)/P(G|Param0))=%s,\n",
+		       spacer, strllike);
 	      if (world->repkind == SINGLECHAIN)
 		fprintf (logg,
 			 "%sStart-tree-ln(L)=ln P(D|G)=%f\n",
@@ -1330,7 +1352,7 @@ print_menu_chain (char type, long chain, long steps,
 	      if (writelog)
 		fprintf (logg, "\n");
 	    }
-//	  prognose_time (nowstr, world, options, steps, spacer);
+//        prognose_time (nowstr, world, options, steps, spacer);
 	}
     }
 }
@@ -1505,8 +1527,8 @@ create_timearchive (timearchive_fmt *** atl, long loci,
       for (i = 0; i < loci + 2; i++)
 	{
 	  (*atl)[h][i].parameters =
-	    (double *) calloc (4 * (numpop2+1) , sizeof (double));
-	//    (double *) calloc (3 * numpop2 + samples + 1, sizeof (double));
+	    (double *) calloc (4 * (numpop2 + 1), sizeof (double));
+	  //    (double *) calloc (3 * numpop2 + samples + 1, sizeof (double));
 	  (*atl)[h][i].param = (*atl)[h][i].parameters;
 	  (*atl)[h][i].param0 = (*atl)[h][i].parameters + numpop2 + 1;
 	  (*atl)[h][i].lparam0 = (*atl)[h][i].param0 + numpop2 + 1;
@@ -1523,8 +1545,8 @@ create_timearchive (timearchive_fmt *** atl, long loci,
 	      (*atl)[h][i].tl[j].kt = (*atl)[h][i].tl[j].wait;
 	      (*atl)[h][i].tl[j].km = &(*atl)[h][i].tl[j].wait[numpop];
 	      (*atl)[h][i].tl[j].p = (*atl)[h][i].tl[j].point;
-	      (*atl)[h][i].tl[j].mindex = (*atl)[h][i].tl[j].point; // the first numpop element are not used
-		  // this is really ugly and should be changed 
+	      (*atl)[h][i].tl[j].mindex = (*atl)[h][i].tl[j].point;	// the first numpop element are not used
+	      // this is really ugly and should be changed 
 	    }
 	}
     }
@@ -1552,13 +1574,13 @@ increase_timearchive (world_fmt * world, long locus, long sample,
 	  world->atl[rep][i].tl[j].data =
 	    (double *) calloc (2 * numpop + numpop2, sizeof (double));
 	  world->atl[rep][i].tl[j].point = world->atl[rep][i].tl[j].data;
-	 world->atl[rep][i].tl[j].wait =
+	  world->atl[rep][i].tl[j].wait =
 	    &world->atl[rep][i].tl[j].data[numpop2];
 	  world->atl[rep][i].tl[j].kt = world->atl[rep][i].tl[j].wait;
 	  world->atl[rep][i].tl[j].km =
 	    &world->atl[rep][i].tl[j].wait[numpop];
 	  world->atl[rep][i].tl[j].p = world->atl[rep][i].tl[j].point;
-	  world->atl[rep][i].tl[j].mindex = world->atl[rep][i].tl[j].point;//ugly:the first numpop elem are not used
+	  world->atl[rep][i].tl[j].mindex = world->atl[rep][i].tl[j].point;	//ugly:the first numpop elem are not used
 	}
       world->atl[rep][i].T = sample;
     }
@@ -1689,7 +1711,7 @@ archive_timelist (tarchive_fmt * atl, vtlist * tl, long T, long np,
       atl->kt[i] = line * (line - 1) * tl[0].age;
       atl->p[i] = (double) whichp (tl[0].from, tl[0].to, i);
     }
-  memset (atl->mindex+ np, 0, sizeof (double) * np * (np - 1));
+  memset (atl->mindex + np, 0, sizeof (double) * np * (np - 1));
   if (tl[0].from != tl[0].to)
     atl->mindex[mm2m (tl[0].from, tl[0].to, np)] += 1;
   if (world->in_last_chain && world->options->mighist)
@@ -1807,9 +1829,9 @@ print_results (world_fmt * world, option_fmt * options, data_fmt * data)
 		 sqrt (1. /
 		       world->atl[rep][world->loci].param[world->numpop2]));
       fprintf (outfile,
-	       "With shape parameter Inv(alpha)=%g ([CV(mu)]^2; CV(mu)=%s,alpha=%g)\n",
-	       1. / world->atl[rep][world->loci].param[world->numpop2],
-	       cva, world->atl[rep][world->loci].param[world->numpop2]);
+	       "With shape parameter Alpha=%g ([1/CV(mu)]^2; CV(mu)=%s)\n",
+	       world->atl[rep][world->loci].param[world->numpop2],
+	       cva);
     }
   if (world->options->replicate)
     {
@@ -2648,28 +2670,26 @@ print_CV (world_fmt * world)
 void
 print_param (FILE * file, boolean usem, double *param, long nn, char spacer[])
 {
-  long i, j;//, fpos;
+  long i, j;			//, fpos;
   long tt = nn;
   long counter;
-  fprintf (file,
-	   "%sPop. Theta    %s\n",
-	   spacer, usem ? "M" : "Theta*M");
+  fprintf (file, "%sPop. Theta    %s\n", spacer, usem ? "M" : "Theta*M");
   for (i = 0; i < nn; i++)
     {
       //fprintf (file, " ");
       counter = 0;
-	    fprintf (file, "%s%3li % 7.5f", spacer,    i+1, param[i]);
+      fprintf (file, "%s%3li % 7.5f", spacer, i + 1, param[i]);
       for (j = 0; j < nn; j++)
 	{
 	  if (i != j)
-	  {
-		if(usem)
-			fprintf (file, "% 7.1f", param[tt++]);
-		else
-		 fprintf (file, "% 7.5f", param[i] * param[tt++]);
-		}
+	    {
+	      if (usem)
+		fprintf (file, "% 7.1f", param[tt++]);
+	      else
+		fprintf (file, "% 7.5f", param[i] * param[tt++]);
+	    }
 	  else
-		fprintf(file," ------");
+	    fprintf (file, " ------");
 	  if (counter++ > 10)
 	    {
 	      counter = 0;
@@ -2678,13 +2698,14 @@ print_param (FILE * file, boolean usem, double *param, long nn, char spacer[])
 	}
       //fpos = ftell (file);
       //fseek (file, fpos - sizeof (char), SEEK_SET);
-      fprintf (file, " \n");//, spacer);
+      fprintf (file, " \n");	//, spacer);
     }
   fprintf (file, " \n");
 }
 
 void
-print_param_old (FILE * file, boolean usem, double *param, long nn, char spacer[])
+print_param_old (FILE * file, boolean usem, double *param, long nn,
+		 char spacer[])
 {
   long i, j, fpos;
   long tt = nn;
